Module commands

Structs

Disable
Disables the accessibility domain. disable
DisableParams
Disables the accessibility domain. disable
Enable
Enables the accessibility domain which causes AXNodeIds to remain consistent between method calls. This turns on accessibility for the page, which can impact performance until accessibility is disabled. enable
EnableParams
Enables the accessibility domain which causes AXNodeIds to remain consistent between method calls. This turns on accessibility for the page, which can impact performance until accessibility is disabled. enable
GetAxNodeAndAncestors
Fetches a node and all ancestors up to and including the root. Requires enable() to have been called previously. getAXNodeAndAncestors
GetAxNodeAndAncestorsParams
Fetches a node and all ancestors up to and including the root. Requires enable() to have been called previously. getAXNodeAndAncestors
GetChildAxNodes
Fetches a particular accessibility node by AXNodeId. Requires enable() to have been called previously. getChildAXNodes
GetChildAxNodesParams
Fetches a particular accessibility node by AXNodeId. Requires enable() to have been called previously. getChildAXNodes
GetFullAxTree
Fetches the entire accessibility tree for the root Document getFullAXTree
GetFullAxTreeParams
Fetches the entire accessibility tree for the root Document getFullAXTree
GetPartialAxTree
Fetches the accessibility node and partial accessibility tree for this DOM node, if it exists. getPartialAXTree
GetPartialAxTreeParams
Fetches the accessibility node and partial accessibility tree for this DOM node, if it exists. getPartialAXTree
GetRootAxNode
Fetches the root node. Requires enable() to have been called previously. getRootAXNode
GetRootAxNodeParams
Fetches the root node. Requires enable() to have been called previously. getRootAXNode
QueryAxTree
Query a DOM node’s accessibility subtree for accessible name and role. This command computes the name and role for all nodes in the subtree, including those that are ignored for accessibility, and returns those that match the specified name and role. If no DOM node is specified, or the DOM node does not exist, the command returns an error. If neither accessibleName or role is specified, it returns all the accessibility nodes in the subtree. queryAXTree
QueryAxTreeParams
Query a DOM node’s accessibility subtree for accessible name and role. This command computes the name and role for all nodes in the subtree, including those that are ignored for accessibility, and returns those that match the specified name and role. If no DOM node is specified, or the DOM node does not exist, the command returns an error. If neither accessibleName or role is specified, it returns all the accessibility nodes in the subtree. queryAXTree

Enums

AccessibilityCommands
DisableMethod
EnableMethod
GetAxNodeAndAncestorsMethod
GetChildAxNodesMethod
GetFullAxTreeMethod
GetPartialAxTreeMethod
GetRootAxNodeMethod
QueryAxTreeMethod