pub struct GetFullAxTreeParams {
pub depth: Option<i64>,
pub frame_id: Option<FrameId>,
}Expand description
Fetches the entire accessibility tree for the root Document getFullAXTree
Fields
depth: Option<i64>The maximum depth at which descendants of the root node should be retrieved. If omitted, the full tree is returned.
frame_id: Option<FrameId>The frame for whose document the AX tree should be retrieved. If omitted, the root frame is used.