pub struct GetPartialAxTreeParams {
pub node_id: Option<NodeId>,
pub backend_node_id: Option<BackendNodeId>,
pub object_id: Option<RemoteObjectId>,
pub fetch_relatives: Option<bool>,
}Expand description
Fetches the accessibility node and partial accessibility tree for this DOM node, if it exists. getPartialAXTree
Fields
node_id: Option<NodeId>Identifier of the node to get the partial accessibility tree for.
backend_node_id: Option<BackendNodeId>Identifier of the backend node to get the partial accessibility tree for.
object_id: Option<RemoteObjectId>JavaScript object id of the node wrapper to get the partial accessibility tree for.
fetch_relatives: Option<bool>Whether to fetch this node’s ancestors, siblings and children. Defaults to true.