Module events

Structs

LoadComplete
The loadComplete event mirrors the load complete event sent by the browser to assistive technology when the web page has finished loading. loadComplete
LoadCompleteParams
The loadComplete event mirrors the load complete event sent by the browser to assistive technology when the web page has finished loading. loadComplete
NodesUpdated
The nodesUpdated event is sent every time a previously requested node has changed the in tree. nodesUpdated
NodesUpdatedParams
The nodesUpdated event is sent every time a previously requested node has changed the in tree. nodesUpdated

Enums

AccessibilityEvents
LoadCompleteMethod
NodesUpdatedMethod