pub struct LoadComplete {
pub method: LoadCompleteMethod,
pub params: LoadCompleteParams,
}Expand description
The loadComplete event mirrors the load complete event sent by the browser to assistive technology when the web page has finished loading. loadComplete
Fields
method: LoadCompleteMethodparams: LoadCompleteParamsImplementations
Sourceimpl LoadComplete
impl LoadComplete
pub const IDENTIFIER: &'static str = "Accessibility.loadComplete"
pub fn identifier(&self) -> &'static str