Module commands

Structs

Disable
Disables animation domain notifications. disable
DisableParams
Disables animation domain notifications. disable
Enable
Enables animation domain notifications. enable
EnableParams
Enables animation domain notifications. enable
GetCurrentTime
Returns the current time of the an animation. getCurrentTime
GetCurrentTimeParams
Returns the current time of the an animation. getCurrentTime
GetPlaybackRate
Gets the playback rate of the document timeline. getPlaybackRate
GetPlaybackRateParams
Gets the playback rate of the document timeline. getPlaybackRate
ReleaseAnimations
Releases a set of animations to no longer be manipulated. releaseAnimations
ReleaseAnimationsParams
Releases a set of animations to no longer be manipulated. releaseAnimations
ResolveAnimation
Gets the remote object of the Animation. resolveAnimation
ResolveAnimationParams
Gets the remote object of the Animation. resolveAnimation
SeekAnimations
Seek a set of animations to a particular time within each animation. seekAnimations
SeekAnimationsParams
Seek a set of animations to a particular time within each animation. seekAnimations
SetPaused
Sets the paused state of a set of animations. setPaused
SetPausedParams
Sets the paused state of a set of animations. setPaused
SetPlaybackRate
Sets the playback rate of the document timeline. setPlaybackRate
SetPlaybackRateParams
Sets the playback rate of the document timeline. setPlaybackRate
SetTiming
Sets the timing of an animation node. setTiming
SetTimingParams
Sets the timing of an animation node. setTiming

Enums

AnimationCommands
DisableMethod
EnableMethod
GetCurrentTimeMethod
GetPlaybackRateMethod
ReleaseAnimationsMethod
ResolveAnimationMethod
SeekAnimationsMethod
SetPausedMethod
SetPlaybackRateMethod
SetTimingMethod