Module commands

Module commands 

Structs

CheckContrast
Runs the contrast check for the target page. Found issues are reported using Audits.issueAdded event. checkContrast
CheckContrastParams
Runs the contrast check for the target page. Found issues are reported using Audits.issueAdded event. checkContrast
CheckFormsIssues
Runs the form issues check for the target page. Found issues are reported using Audits.issueAdded event. checkFormsIssues
CheckFormsIssuesParams
Runs the form issues check for the target page. Found issues are reported using Audits.issueAdded event. checkFormsIssues
Disable
Disables issues domain, prevents further issues from being reported to the client. disable
DisableParams
Disables issues domain, prevents further issues from being reported to the client. disable
Enable
Enables issues domain, sends the issues collected so far to the client by means of the issueAdded event. enable
EnableParams
Enables issues domain, sends the issues collected so far to the client by means of the issueAdded event. enable
GetEncodedResponse
Returns the response body and size if it were re-encoded with the specified settings. Only applies to images. getEncodedResponse
GetEncodedResponseParams
Returns the response body and size if it were re-encoded with the specified settings. Only applies to images. getEncodedResponse

Enums

AuditsCommands
CheckContrastMethod
CheckFormsIssuesMethod
DisableMethod
EnableMethod
GetEncodedResponseEncoding
The encoding to use.
GetEncodedResponseMethod