pub struct Trigger {
pub method: TriggerMethod,
pub params: TriggerParams,
}Expand description
Trigger autofill on a form identified by the fieldId. If the field and related form cannot be autofilled, returns an error. trigger
Fields
method: TriggerMethodparams: TriggerParamsImplementations
Sourceimpl Trigger
impl Trigger
pub const IDENTIFIER: &'static str = "Autofill.trigger"
pub fn identifier(&self) -> &'static str