pub struct SimulateCharacteristicOperationResponse {
pub method: SimulateCharacteristicOperationResponseMethod,
pub params: SimulateCharacteristicOperationResponseParams,
}Expand description
Simulates the response from the characteristic with |characteristicId| for a characteristic operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response. simulateCharacteristicOperationResponse
Fields
method: SimulateCharacteristicOperationResponseMethodparams: SimulateCharacteristicOperationResponseParamsImplementations
Sourceimpl SimulateCharacteristicOperationResponse
impl SimulateCharacteristicOperationResponse
pub const IDENTIFIER: &'static str = "BluetoothEmulation.simulateCharacteristicOperationResponse"
pub fn identifier(&self) -> &'static str