pub struct SimulateDescriptorOperationResponse {
pub method: SimulateDescriptorOperationResponseMethod,
pub params: SimulateDescriptorOperationResponseParams,
}Expand description
Simulates the response from the descriptor with |descriptorId| for a descriptor operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response. simulateDescriptorOperationResponse
Fields
method: SimulateDescriptorOperationResponseMethodparams: SimulateDescriptorOperationResponseParamsImplementations
Sourceimpl SimulateDescriptorOperationResponse
impl SimulateDescriptorOperationResponse
pub const IDENTIFIER: &'static str = "BluetoothEmulation.simulateDescriptorOperationResponse"
pub fn identifier(&self) -> &'static str