pub struct SimulateGattOperationResponse {
pub method: SimulateGattOperationResponseMethod,
pub params: SimulateGattOperationResponseParams,
}Expand description
Simulates the response code from the peripheral with |address| for a GATT operation of |type|. The |code| value follows the HCI Error Codes from Bluetooth Core Specification Vol 2 Part D 1.3 List Of Error Codes. simulateGATTOperationResponse
Fields
method: SimulateGattOperationResponseMethodparams: SimulateGattOperationResponseParamsImplementations
Sourceimpl SimulateGattOperationResponse
impl SimulateGattOperationResponse
pub fn builder() -> SimulateGattOperationResponseBuilder
Sourceimpl SimulateGattOperationResponse
impl SimulateGattOperationResponse
pub const IDENTIFIER: &'static str = "BluetoothEmulation.simulateGATTOperationResponse"
pub fn identifier(&self) -> &'static str