pub struct AddPrivacySandboxEnrollmentOverride {
pub method: AddPrivacySandboxEnrollmentOverrideMethod,
pub params: AddPrivacySandboxEnrollmentOverrideParams,
}Expand description
Allows a site to use privacy sandbox features that require enrollment without the site actually being enrolled. Only supported on page targets. addPrivacySandboxEnrollmentOverride
Fields
method: AddPrivacySandboxEnrollmentOverrideMethodparams: AddPrivacySandboxEnrollmentOverrideParamsImplementations
Sourceimpl AddPrivacySandboxEnrollmentOverride
impl AddPrivacySandboxEnrollmentOverride
pub const IDENTIFIER: &'static str = "Browser.addPrivacySandboxEnrollmentOverride"
pub fn identifier(&self) -> &'static str