pub struct GetWindowForTargetParams {
pub target_id: Option<TargetId>,
}Expand description
Get the browser window that contains the devtools target. getWindowForTarget
Fields
target_id: Option<TargetId>Devtools agent host id. If called as a part of the session, associated targetId is used.