SetPermissionParams

Struct SetPermissionParams 

pub struct SetPermissionParams {
    pub permission: PermissionDescriptor,
    pub setting: PermissionSetting,
    pub origin: Option<String>,
    pub embedded_origin: Option<String>,
    pub browser_context_id: Option<Box<BrowserContextId>>,
}
Set permission settings for given embedding and embedded origins. setPermission

Fields

permission: PermissionDescriptor

Descriptor of permission to override.

setting: PermissionSetting

Setting of the permission.

origin: Option<String>

Embedding origin the permission applies to, all origins if not specified.

embedded_origin: Option<String>

Embedded origin the permission applies to. It is ignored unless the embedding origin is present and valid. If the embedding origin is provided but the embedded origin isn’t, the embedding origin is used as the embedded origin.

browser_context_id: Option<Box<BrowserContextId>>

Context to override. When omitted, default browser context is used.

Implementations

Source

impl SetPermissionParams

pub fn new( permission: impl Into<PermissionDescriptor>, setting: impl Into<PermissionSetting>, ) -> Self