DownloadProgressParams

Struct DownloadProgressParams 

pub struct DownloadProgressParams {
    pub guid: String,
    pub total_bytes: f64,
    pub received_bytes: f64,
    pub state: DownloadProgressState,
    pub file_path: Option<String>,
}
Fired when download makes progress. Last call has |done| == true. downloadProgress

Fields

guid: String

Global unique identifier of the download.

total_bytes: f64

Total expected bytes to download.

received_bytes: f64

Total bytes received.

state: DownloadProgressState

Download status.

file_path: Option<String>

If download is “completed”, provides the path of the downloaded file. Depending on the platform, it is not guaranteed to be set, nor the file is guaranteed to exist.