pub struct DownloadWillBeginParams {
pub frame_id: FrameId,
pub guid: String,
pub url: String,
pub suggested_filename: String,
}Expand description
Fired when page is about to start a download. downloadWillBegin
Fields
frame_id: FrameIdId of the frame that caused the download to begin.
guid: StringGlobal unique identifier of the download.
url: StringURL of the resource being downloaded.
suggested_filename: StringSuggested file name of the resource (the actual name of the file saved on disk may differ).