Module commands

Module commands 

Structs

Disable
Stops observing for sinks and issues. disable
DisableParams
Stops observing for sinks and issues. disable
Enable
Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired. enable
EnableParams
Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired. enable
SetSinkToUse
Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK. setSinkToUse
SetSinkToUseParams
Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK. setSinkToUse
StartDesktopMirroring
Starts mirroring the desktop to the sink. startDesktopMirroring
StartDesktopMirroringParams
Starts mirroring the desktop to the sink. startDesktopMirroring
StartTabMirroring
Starts mirroring the tab to the sink. startTabMirroring
StartTabMirroringParams
Starts mirroring the tab to the sink. startTabMirroring
StopCasting
Stops the active Cast session on the sink. stopCasting
StopCastingParams
Stops the active Cast session on the sink. stopCasting

Enums

CastCommands
DisableMethod
EnableMethod
SetSinkToUseMethod
StartDesktopMirroringMethod
StartTabMirroringMethod
StopCastingMethod