pub struct EnableParams {
pub presentation_url: Option<String>,
}Expand description
Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired. enable
Fields
presentation_url: Option<String>Trait Implementations
Sourceimpl Clone for EnableParams
impl Clone for EnableParams
Sourcefn clone(&self) -> EnableParams
fn clone(&self) -> EnableParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnableParams
impl Debug for EnableParams
Sourceimpl Default for EnableParams
impl Default for EnableParams
Sourcefn default() -> EnableParams
fn default() -> EnableParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EnableParams
impl<'de> Deserialize<'de> for EnableParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EnableParams
impl PartialEq for EnableParams
Sourceimpl Serialize for EnableParams
impl Serialize for EnableParams
impl StructuralPartialEq for EnableParams