pub struct SetSinkToUse {
pub method: SetSinkToUseMethod,
pub params: SetSinkToUseParams,
}Expand description
Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK. setSinkToUse
Fields
method: SetSinkToUseMethodparams: SetSinkToUseParamsImplementations
Sourceimpl SetSinkToUse
impl SetSinkToUse
pub fn builder() -> SetSinkToUseBuilder
Sourceimpl SetSinkToUse
impl SetSinkToUse
pub const IDENTIFIER: &'static str = "Cast.setSinkToUse"
pub fn identifier(&self) -> &'static str