pub struct SetSinkToUseParams {
pub sink_name: String,
}Expand description
Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK. setSinkToUse
Fields
sink_name: StringImplementations