Structs
- Issue
Updated - This is fired whenever the outstanding issue/error message changes. |issueMessage| is empty if there is no issue. issueUpdated
- Issue
Updated Params - This is fired whenever the outstanding issue/error message changes. |issueMessage| is empty if there is no issue. issueUpdated
- Sinks
Updated - This is fired whenever the list of available sinks changes. A sink is a device or a software surface that you can cast to. sinksUpdated
- Sinks
Updated Params - This is fired whenever the list of available sinks changes. A sink is a device or a software surface that you can cast to. sinksUpdated