pub struct SinksUpdated {
pub method: SinksUpdatedMethod,
pub params: SinksUpdatedParams,
}Expand description
This is fired whenever the list of available sinks changes. A sink is a device or a software surface that you can cast to. sinksUpdated
Fields
method: SinksUpdatedMethodparams: SinksUpdatedParamsImplementations
Sourceimpl SinksUpdated
impl SinksUpdated
pub const IDENTIFIER: &'static str = "Cast.sinksUpdated"
pub fn identifier(&self) -> &'static str