pub struct SinksUpdatedParams {
pub sinks: Vec<Sink>,
}Expand description
This is fired whenever the list of available sinks changes. A sink is a device or a software surface that you can cast to. sinksUpdated
Fields
sinks: Vec<Sink>Trait Implementations
Sourceimpl Clone for SinksUpdatedParams
impl Clone for SinksUpdatedParams
Sourcefn clone(&self) -> SinksUpdatedParams
fn clone(&self) -> SinksUpdatedParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SinksUpdatedParams
impl Debug for SinksUpdatedParams
Sourceimpl<'de> Deserialize<'de> for SinksUpdatedParams
impl<'de> Deserialize<'de> for SinksUpdatedParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SinksUpdatedParams
impl PartialEq for SinksUpdatedParams
Sourceimpl Serialize for SinksUpdatedParams
impl Serialize for SinksUpdatedParams
impl StructuralPartialEq for SinksUpdatedParams