pub struct CreateStyleSheetParams {
pub frame_id: FrameId,
pub force: Option<bool>,
}Expand description
Creates a new special “via-inspector” stylesheet in the frame with given frameId.
createStyleSheet
Fields
frame_id: FrameIdIdentifier of the frame where “via-inspector” stylesheet should be created.
force: Option<bool>If true, creates a new stylesheet for every call. If false, returns a stylesheet previously created by a call with force=false for the frame’s document if it exists or creates a new stylesheet (default: false).
Implementations