GetLayersForNode

Struct GetLayersForNode 

pub struct GetLayersForNode {
    pub method: GetLayersForNodeMethod,
    pub params: GetLayersForNodeParams,
}
Returns all layers parsed by the rendering engine for the tree scope of a node. Given a DOM element identified by nodeId, getLayersForNode returns the root layer for the nearest ancestor document or shadow root. The layer root contains the full layer tree for the tree scope and their ordering. getLayersForNode

Fields

method: GetLayersForNodeMethodparams: GetLayersForNodeParams

Implementations

Source

impl GetLayersForNode

Source

impl GetLayersForNode

pub const IDENTIFIER: &'static str = "CSS.getLayersForNode"

pub fn identifier(&self) -> &'static str