ResolveValues

Struct ResolveValues 

pub struct ResolveValues {
    pub method: ResolveValuesMethod,
    pub params: ResolveValuesParams,
}
Resolve the specified values in the context of the provided element. For example, a value of ‘1em’ is evaluated according to the computed ‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be resolved to ‘3px’. If the propertyName was specified the values are resolved as if they were property’s declaration. If a value cannot be parsed according to the provided property syntax, the value is parsed using combined syntax as if null propertyName was provided. If the value cannot be resolved even then, return the provided value without any changes. Note: this function currently does not resolve CSS random() function, it returns unmodified random() function parts.` resolveValues

Fields

method: ResolveValuesMethodparams: ResolveValuesParams

Implementations

Source

impl ResolveValues

Source

impl ResolveValues

pub const IDENTIFIER: &'static str = "CSS.resolveValues"

pub fn identifier(&self) -> &'static str