pub struct SetEffectivePropertyValueForNode {
pub method: SetEffectivePropertyValueForNodeMethod,
pub params: SetEffectivePropertyValueForNodeParams,
}Expand description
Find a rule with the given active property for the given node and set the new value for this property setEffectivePropertyValueForNode
Fields
method: SetEffectivePropertyValueForNodeMethodparams: SetEffectivePropertyValueForNodeParamsImplementations
Sourceimpl SetEffectivePropertyValueForNode
impl SetEffectivePropertyValueForNode
pub fn builder() -> SetEffectivePropertyValueForNodeBuilder
Sourceimpl SetEffectivePropertyValueForNode
impl SetEffectivePropertyValueForNode
pub const IDENTIFIER: &'static str = "CSS.setEffectivePropertyValueForNode"
pub fn identifier(&self) -> &'static str