pub struct StopRuleUsageTracking {
pub method: StopRuleUsageTrackingMethod,
pub params: StopRuleUsageTrackingParams,
}Expand description
Stop tracking rule usage and return the list of rules that were used since last call to
takeCoverageDelta (or since start of coverage instrumentation).
stopRuleUsageTracking
Fields
method: StopRuleUsageTrackingMethodparams: StopRuleUsageTrackingParamsImplementations
Sourceimpl StopRuleUsageTracking
impl StopRuleUsageTracking
pub fn builder() -> StopRuleUsageTrackingBuilder
Sourceimpl StopRuleUsageTracking
impl StopRuleUsageTracking
pub const IDENTIFIER: &'static str = "CSS.stopRuleUsageTracking"
pub fn identifier(&self) -> &'static str