pub struct TrackComputedStyleUpdates {
pub method: TrackComputedStyleUpdatesMethod,
pub params: TrackComputedStyleUpdatesParams,
}Expand description
Starts tracking the given computed styles for updates. The specified array of properties replaces the one previously specified. Pass empty array to disable tracking. Use takeComputedStyleUpdates to retrieve the list of nodes that had properties modified. The changes to computed style properties are only tracked for nodes pushed to the front-end by the DOM agent. If no changes to the tracked properties occur after the node has been pushed to the front-end, no updates will be issued for the node. trackComputedStyleUpdates
Fields
method: TrackComputedStyleUpdatesMethodparams: TrackComputedStyleUpdatesParamsImplementations
Sourceimpl TrackComputedStyleUpdates
impl TrackComputedStyleUpdates
pub const IDENTIFIER: &'static str = "CSS.trackComputedStyleUpdates"
pub fn identifier(&self) -> &'static str