pub struct TrackComputedStyleUpdatesForNode {
pub method: TrackComputedStyleUpdatesForNodeMethod,
pub params: TrackComputedStyleUpdatesForNodeParams,
}Expand description
Starts tracking the given node for the computed style updates
and whenever the computed style is updated for node, it queues
a computedStyleUpdated event with throttling.
There can only be 1 node tracked for computed style updates
so passing a new node id removes tracking from the previous node.
Pass undefined to disable tracking.
trackComputedStyleUpdatesForNode
Fields
method: TrackComputedStyleUpdatesForNodeMethodparams: TrackComputedStyleUpdatesForNodeParamsImplementations
Sourceimpl TrackComputedStyleUpdatesForNode
impl TrackComputedStyleUpdatesForNode
pub fn builder() -> TrackComputedStyleUpdatesForNodeBuilder
Sourceimpl TrackComputedStyleUpdatesForNode
impl TrackComputedStyleUpdatesForNode
pub const IDENTIFIER: &'static str = "CSS.trackComputedStyleUpdatesForNode"
pub fn identifier(&self) -> &'static str