pub struct GetMatchedStylesForNodeResult {Show 14 fields
pub inline_style: Option<CssStyle>,
pub attributes_style: Option<CssStyle>,
pub matched_css_rules: Option<Vec<RuleMatch>>,
pub pseudo_elements: Option<Vec<PseudoElementMatches>>,
pub inherited: Option<Vec<InheritedStyleEntry>>,
pub inherited_pseudo_elements: Option<Vec<InheritedPseudoElementMatches>>,
pub css_keyframes_rules: Option<Vec<CssKeyframesRule>>,
pub css_position_try_rules: Option<Vec<CssPositionTryRule>>,
pub active_position_fallback_index: Option<i64>,
pub css_property_rules: Option<Vec<CssPropertyRule>>,
pub css_property_registrations: Option<Vec<CssPropertyRegistration>>,
pub css_at_rules: Option<Vec<CssAtRule>>,
pub parent_layout_node_id: Option<NodeId>,
pub css_function_rules: Option<Vec<CssFunctionRule>>,
}Fields
inline_style: Option<CssStyle>Inline style for the specified DOM node.
attributes_style: Option<CssStyle>Attribute-defined element style (e.g. resulting from “width=20 height=100%”).
matched_css_rules: Option<Vec<RuleMatch>>CSS rules matching this node, from all applicable stylesheets.
pseudo_elements: Option<Vec<PseudoElementMatches>>Pseudo style matches for this node.
inherited: Option<Vec<InheritedStyleEntry>>A chain of inherited styles (from the immediate node parent up to the DOM tree root).
inherited_pseudo_elements: Option<Vec<InheritedPseudoElementMatches>>A chain of inherited pseudo element styles (from the immediate node parent up to the DOM tree root).
css_keyframes_rules: Option<Vec<CssKeyframesRule>>A list of CSS keyframed animations matching this node.
css_position_try_rules: Option<Vec<CssPositionTryRule>>A list of CSS @position-try rules matching this node, based on the position-try-fallbacks property.
active_position_fallback_index: Option<i64>Index of the active fallback in the applied position-try-fallback property, will not be set if there is no active position-try fallback.
css_property_rules: Option<Vec<CssPropertyRule>>A list of CSS at-property rules matching this node.
css_property_registrations: Option<Vec<CssPropertyRegistration>>A list of CSS property registrations matching this node.
css_at_rules: Option<Vec<CssAtRule>>A list of simple @rules matching this node or its pseudo-elements.
parent_layout_node_id: Option<NodeId>Id of the first parent element that does not have display: contents.
css_function_rules: Option<Vec<CssFunctionRule>>A list of CSS at-function rules referenced by styles of this node.