pub struct CopyTo {
pub method: CopyToMethod,
pub params: CopyToParams,
}Expand description
Creates a deep copy of the specified node and places it into the target container before the given anchor. copyTo
Fields
method: CopyToMethodparams: CopyToParamsImplementations
Sourceimpl CopyTo
impl CopyTo
pub const IDENTIFIER: &'static str = "DOM.copyTo"
pub fn identifier(&self) -> &'static str