pub struct DescribeNode {
pub method: DescribeNodeMethod,
pub params: DescribeNodeParams,
}Expand description
Describes node given its id, does not require domain to be enabled. Does not start tracking any objects, can be used for automation. describeNode
Fields
method: DescribeNodeMethodparams: DescribeNodeParamsImplementations
Sourceimpl DescribeNode
impl DescribeNode
pub fn builder() -> DescribeNodeBuilder
Sourceimpl DescribeNode
impl DescribeNode
pub const IDENTIFIER: &'static str = "DOM.describeNode"
pub fn identifier(&self) -> &'static str