pub struct GetAnchorElementParams {
pub node_id: Box<NodeId>,
pub anchor_specifier: Option<String>,
}Expand description
Returns the target anchor element of the given anchor query according to https://www.w3.org/TR/css-anchor-position-1/#target. getAnchorElement
Fields
node_id: Box<NodeId>Id of the positioned element from which to find the anchor.
anchor_specifier: Option<String>An optional anchor specifier, as defined in https://www.w3.org/TR/css-anchor-position-1/#anchor-specifier. If not provided, it will return the implicit anchor element for the given positioned element.
Implementations