pub struct GetContainerForNodeParams {
pub node_id: Box<NodeId>,
pub container_name: Option<String>,
pub physical_axes: Option<PhysicalAxes>,
pub logical_axes: Option<LogicalAxes>,
pub queries_scroll_state: Option<bool>,
pub queries_anchored: Option<bool>,
}Expand description
Returns the query container of the given node based on container query conditions: containerName, physical and logical axes, and whether it queries scroll-state or anchored elements. If no axes are provided and queriesScrollState is false, the style container is returned, which is the direct parent or the closest element with a matching container-name. getContainerForNode
Fields
node_id: Box<NodeId>container_name: Option<String>physical_axes: Option<PhysicalAxes>logical_axes: Option<LogicalAxes>queries_scroll_state: Option<bool>queries_anchored: Option<bool>Implementations