pub struct GetElementByRelationParams {
pub node_id: Box<NodeId>,
pub relation: GetElementByRelationRelation,
}Expand description
Returns the NodeId of the matched element according to certain relations. getElementByRelation
Fields
node_id: Box<NodeId>Id of the node from which to query the relation.
relation: GetElementByRelationRelationType of relation to get.
Implementations