pub struct GetNodeStackTracesParams {
pub node_id: Box<NodeId>,
}Expand description
Gets stack traces associated with a Node. As of now, only provides stack trace for Node creation. getNodeStackTraces
Fields
node_id: Box<NodeId>Id of the node to get stack traces for.
Implementations