pub struct GetNodesForSubtreeByStyleParams {
pub node_id: Box<NodeId>,
pub computed_styles: Vec<CssComputedStyleProperty>,
pub pierce: Option<bool>,
}Expand description
Finds nodes with a given computed style in a subtree. getNodesForSubtreeByStyle
Fields
node_id: Box<NodeId>Node ID pointing to the root of a subtree.
computed_styles: Vec<CssComputedStyleProperty>The style to filter nodes by (includes nodes if any of properties matches).
pierce: Option<bool>Whether or not iframes and shadow roots in the same target should be traversed when returning the results (default is false).
Implementations