pub struct GetTopLayerElements {
pub method: GetTopLayerElementsMethod,
pub params: GetTopLayerElementsParams,
}Expand description
Returns NodeIds of current top layer elements. Top layer is rendered closest to the user within a viewport, therefore its elements always appear on top of all other content. getTopLayerElements
Fields
method: GetTopLayerElementsMethodparams: GetTopLayerElementsParamsImplementations
Sourceimpl GetTopLayerElements
impl GetTopLayerElements
pub fn builder() -> GetTopLayerElementsBuilder
Sourceimpl GetTopLayerElements
impl GetTopLayerElements
pub const IDENTIFIER: &'static str = "DOM.getTopLayerElements"
pub fn identifier(&self) -> &'static str