pub struct MoveToParams {
pub node_id: Box<NodeId>,
pub target_node_id: NodeId,
pub insert_before_node_id: Option<NodeId>,
}Expand description
Moves node into the new container, places it before the given anchor. moveTo
Fields
node_id: Box<NodeId>Id of the node to move.
target_node_id: NodeIdId of the element to drop the moved node into.
insert_before_node_id: Option<NodeId>Drop node before this one (if absent, the moved node becomes the last child of
targetNodeId).
Implementations