RequestChildNodes

Struct RequestChildNodes 

pub struct RequestChildNodes {
    pub method: RequestChildNodesMethod,
    pub params: RequestChildNodesParams,
}
Requests that children of the node with given id are returned to the caller in form of setChildNodes events where not only immediate children are retrieved, but all children down to the specified depth. requestChildNodes

Fields

method: RequestChildNodesMethodparams: RequestChildNodesParams

Implementations

Source

impl RequestChildNodes

Source

impl RequestChildNodes

pub const IDENTIFIER: &'static str = "DOM.requestChildNodes"

pub fn identifier(&self) -> &'static str