RequestNode

Struct RequestNode 

pub struct RequestNode {
    pub method: RequestNodeMethod,
    pub params: RequestNodeParams,
}
Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of setChildNodes notifications. requestNode

Fields

method: RequestNodeMethodparams: RequestNodeParams

Implementations

Source

impl RequestNode

Source

impl RequestNode

pub const IDENTIFIER: &'static str = "DOM.requestNode"

pub fn identifier(&self) -> &'static str