pub struct RequestNodeParams {
pub object_id: RemoteObjectId,
}Expand description
Requests that the node is sent to the caller given the JavaScript node object reference. All
nodes that form the path from the node to the root are also sent to the client as a series of
setChildNodes notifications.
requestNode
Fields
object_id: RemoteObjectIdJavaScript object id to convert into node.
Implementations
Sourceimpl RequestNodeParams
impl RequestNodeParams
pub fn new(object_id: impl Into<RemoteObjectId>) -> Self