pub struct SetAttributesAsText {
pub method: SetAttributesAsTextMethod,
pub params: SetAttributesAsTextParams,
}Expand description
Sets attributes on element with given id. This method is useful when user edits some existing attribute value and types in several attribute name/value pairs. setAttributesAsText
Fields
method: SetAttributesAsTextMethodparams: SetAttributesAsTextParamsImplementations
Sourceimpl SetAttributesAsText
impl SetAttributesAsText
pub fn builder() -> SetAttributesAsTextBuilder
Sourceimpl SetAttributesAsText
impl SetAttributesAsText
pub const IDENTIFIER: &'static str = "DOM.setAttributesAsText"
pub fn identifier(&self) -> &'static str