pub struct SetAttributesAsTextParams {
pub node_id: Box<NodeId>,
pub text: String,
pub name: Option<String>,
}Expand description
Sets attributes on element with given id. This method is useful when user edits some existing attribute value and types in several attribute name/value pairs. setAttributesAsText
Fields
node_id: Box<NodeId>Id of the element to set attributes for.
text: StringText with a number of attributes. Will parse this text using HTML parser.
name: Option<String>Attribute name to replace with new attributes derived from text in case text parsed successfully.
Implementations