pub struct SetChildNodes {
pub method: SetChildNodesMethod,
pub params: SetChildNodesParams,
}Expand description
Fired when backend wants to provide client with the missing DOM structure. This happens upon most of the calls requesting node ids. setChildNodes
Fields
method: SetChildNodesMethodparams: SetChildNodesParamsImplementations
Sourceimpl SetChildNodes
impl SetChildNodes
pub const IDENTIFIER: &'static str = "DOM.setChildNodes"
pub fn identifier(&self) -> &'static str