pub struct SetChildNodesParams {
pub parent_id: NodeId,
pub nodes: Vec<Node>,
}Expand description
Fired when backend wants to provide client with the missing DOM structure. This happens upon most of the calls requesting node ids. setChildNodes
Fields
parent_id: NodeIdParent node id to populate with children.
nodes: Vec<Node>Child nodes array.