pub struct AddScreenParams {
pub left: i64,
pub top: i64,
pub width: i64,
pub height: i64,
pub work_area_insets: Option<WorkAreaInsets>,
pub device_pixel_ratio: Option<f64>,
pub rotation: Option<i64>,
pub color_depth: Option<i64>,
pub label: Option<String>,
pub is_internal: Option<bool>,
}Expand description
Add a new screen to the device. Only supported in headless mode. addScreen
Fields
left: i64Offset of the left edge of the screen in pixels.
top: i64Offset of the top edge of the screen in pixels.
width: i64The width of the screen in pixels.
height: i64The height of the screen in pixels.
work_area_insets: Option<WorkAreaInsets>Specifies the screen’s work area. Default is entire screen.
device_pixel_ratio: Option<f64>Specifies the screen’s device pixel ratio. Default is 1.
rotation: Option<i64>Specifies the screen’s rotation angle. Available values are 0, 90, 180 and 270. Default is 0.
color_depth: Option<i64>Specifies the screen’s color depth in bits. Default is 24.
label: Option<String>Specifies the descriptive label for the screen. Default is none.
is_internal: Option<bool>Indicates whether the screen is internal to the device or external, attached to the device. Default is false.
Implementations