pub struct ClearDevicePostureOverride {
pub method: ClearDevicePostureOverrideMethod,
pub params: ClearDevicePostureOverrideParams,
}Expand description
Clears a device posture override set with either setDeviceMetricsOverride() or setDevicePostureOverride() and starts using posture information from the platform again. Does nothing if no override is set. clearDevicePostureOverride
Fields
method: ClearDevicePostureOverrideMethodparams: ClearDevicePostureOverrideParamsImplementations
Sourceimpl ClearDevicePostureOverride
impl ClearDevicePostureOverride
pub const IDENTIFIER: &'static str = "Emulation.clearDevicePostureOverride"
pub fn identifier(&self) -> &'static str