ClearDisplayFeaturesOverride

Struct ClearDisplayFeaturesOverride 

pub struct ClearDisplayFeaturesOverride {
    pub method: ClearDisplayFeaturesOverrideMethod,
    pub params: ClearDisplayFeaturesOverrideParams,
}
Clears the display features override set with either setDeviceMetricsOverride() or setDisplayFeaturesOverride() and starts using display features from the platform again. Does nothing if no override is set. clearDisplayFeaturesOverride

Fields

method: ClearDisplayFeaturesOverrideMethodparams: ClearDisplayFeaturesOverrideParams

Implementations

Source

impl ClearDisplayFeaturesOverride

Source

impl ClearDisplayFeaturesOverride

pub const IDENTIFIER: &'static str = "Emulation.clearDisplayFeaturesOverride"

pub fn identifier(&self) -> &'static str