pub struct GetScreenInfos {
pub method: GetScreenInfosMethod,
pub params: GetScreenInfosParams,
}Expand description
Returns device’s screen configuration. In headful mode, the physical screens configuration is returned, whereas in headless mode, a virtual headless screen configuration is provided instead. getScreenInfos
Fields
method: GetScreenInfosMethodparams: GetScreenInfosParamsImplementations
Sourceimpl GetScreenInfos
impl GetScreenInfos
pub fn builder() -> GetScreenInfosBuilder
Sourceimpl GetScreenInfos
impl GetScreenInfos
pub const IDENTIFIER: &'static str = "Emulation.getScreenInfos"
pub fn identifier(&self) -> &'static str