pub struct GetScreenInfosParams {}Expand description
Returns device’s screen configuration. In headful mode, the physical screens configuration is returned, whereas in headless mode, a virtual headless screen configuration is provided instead. getScreenInfos