pub struct SetTimezoneOverrideParams {
pub timezone_id: String,
}Expand description
Overrides default host system timezone with the specified one. setTimezoneOverride
Fields
timezone_id: StringThe timezone identifier. List of supported timezones: https://source.chromium.org/chromium/chromium/deps/icu.git/+/faee8bc70570192d82d2978a71e2a615788597d1:source/data/misc/metaZones.txt If empty, disables the override and restores default host system timezone.
Implementations