Module commands

Structs

ClearStorageItems
Clears extension storage in the given storageArea. clearStorageItems
ClearStorageItemsParams
Clears extension storage in the given storageArea. clearStorageItems
GetExtensions
Gets a list of all unpacked extensions. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. getExtensions
GetExtensionsParams
Gets a list of all unpacked extensions. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. getExtensions
GetStorageItems
Gets data from extension storage in the given storageArea. If keys is specified, these are used to filter the result. getStorageItems
GetStorageItemsParams
Gets data from extension storage in the given storageArea. If keys is specified, these are used to filter the result. getStorageItems
LoadUnpacked
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. loadUnpacked
LoadUnpackedParams
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. loadUnpacked
RemoveStorageItems
Removes keys from extension storage in the given storageArea. removeStorageItems
RemoveStorageItemsParams
Removes keys from extension storage in the given storageArea. removeStorageItems
SetStorageItems
Sets values in extension storage in the given storageArea. The provided values will be merged with existing values in the storage area. setStorageItems
SetStorageItemsParams
Sets values in extension storage in the given storageArea. The provided values will be merged with existing values in the storage area. setStorageItems
TriggerAction
Runs an extension default action. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. triggerAction
TriggerActionParams
Runs an extension default action. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. triggerAction
Uninstall
Uninstalls an unpacked extension (others not supported) from the profile. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging. uninstall
UninstallParams
Uninstalls an unpacked extension (others not supported) from the profile. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging. uninstall

Enums

ClearStorageItemsMethod
ExtensionsCommands
GetExtensionsMethod
GetStorageItemsMethod
LoadUnpackedMethod
RemoveStorageItemsMethod
SetStorageItemsMethod
TriggerActionMethod
UninstallMethod