pub struct LoadUnpacked {
pub method: LoadUnpackedMethod,
pub params: LoadUnpackedParams,
}Expand description
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. loadUnpacked
Fields
method: LoadUnpackedMethodparams: LoadUnpackedParamsImplementations
Sourceimpl LoadUnpacked
impl LoadUnpacked
pub fn builder() -> LoadUnpackedBuilder
Sourceimpl LoadUnpacked
impl LoadUnpacked
pub const IDENTIFIER: &'static str = "Extensions.loadUnpacked"
pub fn identifier(&self) -> &'static str