pub struct SetStorageItems {
pub method: SetStorageItemsMethod,
pub params: SetStorageItemsParams,
}Expand description
Sets values in extension storage in the given storageArea. The provided values
will be merged with existing values in the storage area.
setStorageItems
Fields
method: SetStorageItemsMethodparams: SetStorageItemsParamsImplementations
Sourceimpl SetStorageItems
impl SetStorageItems
pub fn builder() -> SetStorageItemsBuilder
Sourceimpl SetStorageItems
impl SetStorageItems
pub const IDENTIFIER: &'static str = "Extensions.setStorageItems"
pub fn identifier(&self) -> &'static str