pub struct EnableParams {
pub disable_rejection_delay: Option<bool>,
}Fields
disable_rejection_delay: Option<bool>Allows callers to disable the promise rejection delay that would normally happen, if this is unimportant to what’s being tested. (step 4 of https://fedidcg.github.io/FedCM/#browser-api-rp-sign-in)