pub struct ResetCooldown {
pub method: ResetCooldownMethod,
pub params: ResetCooldownParams,
}Expand description
Resets the cooldown time, if any, to allow the next FedCM call to show a dialog even if one was recently dismissed by the user. resetCooldown
Fields
method: ResetCooldownMethodparams: ResetCooldownParamsImplementations
Sourceimpl ResetCooldown
impl ResetCooldown
pub fn builder() -> ResetCooldownBuilder
Sourceimpl ResetCooldown
impl ResetCooldown
pub const IDENTIFIER: &'static str = "FedCm.resetCooldown"
pub fn identifier(&self) -> &'static str