pub struct ContinueRequestParams {
pub request_id: RequestId,
pub url: Option<String>,
pub method: Option<String>,
pub post_data: Option<Binary>,
pub headers: Option<Vec<HeaderEntry>>,
pub intercept_response: Option<bool>,
}Expand description
Continues the request, optionally modifying some of its parameters. continueRequest
Fields
request_id: RequestIdAn id the client received in requestPaused event.
url: Option<String>If set, the request url will be modified in a way that’s not observable by page.
method: Option<String>If set, the request method is overridden.
post_data: Option<Binary>If set, overrides the post data in the request.
headers: Option<Vec<HeaderEntry>>If set, overrides the request headers. Note that the overrides do not extend to subsequent redirect hops, if a redirect happens. Another override may be applied to a different request produced by a redirect.
intercept_response: Option<bool>If set, overrides response interception behavior for this request.
Implementations