GetResponseBody

Struct GetResponseBody 

pub struct GetResponseBody {
    pub method: GetResponseBodyMethod,
    pub params: GetResponseBodyParams,
}
Causes the body of the response to be received from the server and returned as a single string. May only be issued for a request that is paused in the Response stage and is mutually exclusive with takeResponseBodyForInterceptionAsStream. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior. Note that the response body is not available for redirects. Requests paused in the redirect received state may be differentiated by responseCode and presence of location response header, see comments to requestPaused for details. getResponseBody

Fields

method: GetResponseBodyMethodparams: GetResponseBodyParams

Implementations

Source

impl GetResponseBody

Source

impl GetResponseBody

pub const IDENTIFIER: &'static str = "Fetch.getResponseBody"

pub fn identifier(&self) -> &'static str