pub struct AuthRequiredParams {
pub request_id: RequestId,
pub request: Request,
pub frame_id: FrameId,
pub resource_type: ResourceType,
pub auth_challenge: AuthChallenge,
}Expand description
Issued when the domain is enabled with handleAuthRequests set to true. The request is paused until client responds with continueWithAuth. authRequired
Fields
request_id: RequestIdEach request the page makes will have a unique id.
request: RequestThe details of the request.
frame_id: FrameIdThe id of the frame that initiated the request.
resource_type: ResourceTypeHow the requested resource will be used.
auth_challenge: AuthChallengeDetails of the Authorization Challenge encountered. If this is set, client should respond with continueRequest that contains AuthChallengeResponse.