RequestPaused

Struct RequestPaused 

pub struct RequestPaused {
    pub method: RequestPausedMethod,
    pub params: RequestPausedParams,
}
Issued when the domain is enabled and the request URL matches the specified filter. The request is paused until the client responds with one of continueRequest, failRequest or fulfillRequest. The stage of the request can be determined by presence of responseErrorReason and responseStatusCode – the request is at the response stage if either of these fields is present and in the request stage otherwise. Redirect responses and subsequent requests are reported similarly to regular responses and requests. Redirect responses may be distinguished by the value of responseStatusCode (which is one of 301, 302, 303, 307, 308) along with presence of the location header. Requests resulting from a redirect will have redirectedRequestId field set. requestPaused

Fields

method: RequestPausedMethodparams: RequestPausedParams

Implementations

Source

impl RequestPaused

pub const IDENTIFIER: &'static str = "Fetch.requestPaused"

pub fn identifier(&self) -> &'static str