pub struct BeginFrame {
pub method: BeginFrameMethod,
pub params: BeginFrameParams,
}Expand description
Sends a BeginFrame to the target and returns when the frame was completed. Optionally captures a screenshot from the resulting frame. Requires that the target was created with enabled BeginFrameControl. Designed for use with –run-all-compositor-stages-before-draw, see also https://goo.gle/chrome-headless-rendering for more background. beginFrame
Fields
method: BeginFrameMethodparams: BeginFrameParamsImplementations
Sourceimpl BeginFrame
impl BeginFrame
pub fn builder() -> BeginFrameBuilder
Sourceimpl BeginFrame
impl BeginFrame
pub const IDENTIFIER: &'static str = "HeadlessExperimental.beginFrame"
pub fn identifier(&self) -> &'static str