pub struct BeginFrameResult {
pub has_damage: bool,
pub screenshot_data: Option<Binary>,
}Fields
has_damage: boolWhether the BeginFrame resulted in damage and, thus, a new frame was committed to the display. Reported for diagnostic uses, may be removed in the future.
screenshot_data: Option<Binary>Base64-encoded image data of the screenshot, if one was requested and successfully taken.