Module commands

Module commands 

Structs

CancelDragging
Cancels any active dragging in the page. cancelDragging
CancelDraggingParams
Cancels any active dragging in the page. cancelDragging
DispatchDragEvent
Dispatches a drag event into the page. dispatchDragEvent
DispatchDragEventParams
Dispatches a drag event into the page. dispatchDragEvent
DispatchKeyEvent
Dispatches a key event to the page. dispatchKeyEvent
DispatchKeyEventParams
Dispatches a key event to the page. dispatchKeyEvent
DispatchMouseEvent
Dispatches a mouse event to the page. dispatchMouseEvent
DispatchMouseEventParams
Dispatches a mouse event to the page. dispatchMouseEvent
DispatchTouchEvent
Dispatches a touch event to the page. dispatchTouchEvent
DispatchTouchEventParams
Dispatches a touch event to the page. dispatchTouchEvent
EmulateTouchFromMouseEvent
Emulates touch event from the mouse event parameters. emulateTouchFromMouseEvent
EmulateTouchFromMouseEventParams
Emulates touch event from the mouse event parameters. emulateTouchFromMouseEvent
ImeSetComposition
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition. imeSetComposition
ImeSetCompositionParams
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition. imeSetComposition
InsertText
This method emulates inserting text that doesn’t come from a key press, for example an emoji keyboard or an IME. insertText
InsertTextParams
This method emulates inserting text that doesn’t come from a key press, for example an emoji keyboard or an IME. insertText
SetIgnoreInputEvents
Ignores input events (useful while auditing page). setIgnoreInputEvents
SetIgnoreInputEventsParams
Ignores input events (useful while auditing page). setIgnoreInputEvents
SetInterceptDrags
Prevents default drag and drop behavior and instead emits Input.dragIntercepted events. Drag and drop behavior can be directly controlled via Input.dispatchDragEvent. setInterceptDrags
SetInterceptDragsParams
Prevents default drag and drop behavior and instead emits Input.dragIntercepted events. Drag and drop behavior can be directly controlled via Input.dispatchDragEvent. setInterceptDrags
SynthesizePinchGesture
Synthesizes a pinch gesture over a time period by issuing appropriate touch events. synthesizePinchGesture
SynthesizePinchGestureParams
Synthesizes a pinch gesture over a time period by issuing appropriate touch events. synthesizePinchGesture
SynthesizeScrollGesture
Synthesizes a scroll gesture over a time period by issuing appropriate touch events. synthesizeScrollGesture
SynthesizeScrollGestureParams
Synthesizes a scroll gesture over a time period by issuing appropriate touch events. synthesizeScrollGesture
SynthesizeTapGesture
Synthesizes a tap gesture over a time period by issuing appropriate touch events. synthesizeTapGesture
SynthesizeTapGestureParams
Synthesizes a tap gesture over a time period by issuing appropriate touch events. synthesizeTapGesture

Enums

CancelDraggingMethod
DispatchDragEventMethod
DispatchDragEventType
Type of the drag event.
DispatchKeyEventMethod
DispatchKeyEventType
Type of the key event.
DispatchMouseEventMethod
DispatchMouseEventPointerType
Pointer type (default: “mouse”).
DispatchMouseEventType
Type of the mouse event.
DispatchTouchEventMethod
DispatchTouchEventType
Type of the touch event. TouchEnd and TouchCancel must not contain any touch points, while TouchStart and TouchMove must contains at least one.
EmulateTouchFromMouseEventMethod
EmulateTouchFromMouseEventType
Type of the mouse event.
ImeSetCompositionMethod
InputCommands
InsertTextMethod
SetIgnoreInputEventsMethod
SetInterceptDragsMethod
SynthesizePinchGestureMethod
SynthesizeScrollGestureMethod
SynthesizeTapGestureMethod