pub struct DispatchDragEventParams {
pub type: DispatchDragEventType,
pub x: f64,
pub y: f64,
pub data: DragData,
pub modifiers: Option<i64>,
}Expand description
Dispatches a drag event into the page. dispatchDragEvent
Fields
type: DispatchDragEventTypeType of the drag event.
x: f64X coordinate of the event relative to the main frame’s viewport in CSS pixels.
y: f64Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
data: DragDatamodifiers: Option<i64>Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0).
Implementations