pub struct DispatchMouseEventParams {Show 16 fields
pub type: DispatchMouseEventType,
pub x: f64,
pub y: f64,
pub modifiers: Option<i64>,
pub timestamp: Option<TimeSinceEpoch>,
pub button: Option<MouseButton>,
pub buttons: Option<i64>,
pub click_count: Option<i64>,
pub force: Option<f64>,
pub tangential_pressure: Option<f64>,
pub tilt_x: Option<f64>,
pub tilt_y: Option<f64>,
pub twist: Option<i64>,
pub delta_x: Option<f64>,
pub delta_y: Option<f64>,
pub pointer_type: Option<DispatchMouseEventPointerType>,
}Expand description
Dispatches a mouse event to the page. dispatchMouseEvent
Fields
type: DispatchMouseEventTypeType of the mouse event.
x: f64X coordinate of the event relative to the main frame’s viewport in CSS pixels.
y: f64Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
modifiers: Option<i64>Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0).
timestamp: Option<TimeSinceEpoch>Time at which the event occurred.
Mouse button (default: “none”).
A number indicating which buttons are pressed on the mouse when a mouse event is triggered. Left=1, Right=2, Middle=4, Back=8, Forward=16, None=0.
click_count: Option<i64>Number of times the mouse button was clicked (default: 0).
force: Option<f64>The normalized pressure, which has a range of [0,1] (default: 0).
tangential_pressure: Option<f64>The normalized tangential pressure, which has a range of [-1,1] (default: 0).
tilt_x: Option<f64>The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0).
tilt_y: Option<f64>The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).
twist: Option<i64>The clockwise rotation of a pen stylus around its own major axis, in degrees in the range [0,359] (default: 0).
delta_x: Option<f64>X delta in CSS pixels for mouse wheel event (default: 0).
delta_y: Option<f64>Y delta in CSS pixels for mouse wheel event (default: 0).
pointer_type: Option<DispatchMouseEventPointerType>Pointer type (default: “mouse”).
Implementations