ImeSetComposition

Struct ImeSetComposition 

pub struct ImeSetComposition {
    pub method: ImeSetCompositionMethod,
    pub params: ImeSetCompositionParams,
}
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition. imeSetComposition

Fields

method: ImeSetCompositionMethodparams: ImeSetCompositionParams

Implementations

Source

impl ImeSetComposition

Source

impl ImeSetComposition

pub const IDENTIFIER: &'static str = "Input.imeSetComposition"

pub fn identifier(&self) -> &'static str