pub struct SetInterceptDrags {
pub method: SetInterceptDragsMethod,
pub params: SetInterceptDragsParams,
}Expand description
Prevents default drag and drop behavior and instead emits Input.dragIntercepted events.
Drag and drop behavior can be directly controlled via Input.dispatchDragEvent.
setInterceptDrags
Fields
method: SetInterceptDragsMethodparams: SetInterceptDragsParamsImplementations
Sourceimpl SetInterceptDrags
impl SetInterceptDrags
pub fn builder() -> SetInterceptDragsBuilder
Sourceimpl SetInterceptDrags
impl SetInterceptDrags
pub const IDENTIFIER: &'static str = "Input.setInterceptDrags"
pub fn identifier(&self) -> &'static str