pub struct SetInterceptDragsParams {
pub enabled: bool,
}Expand description
Prevents default drag and drop behavior and instead emits Input.dragIntercepted events.
Drag and drop behavior can be directly controlled via Input.dispatchDragEvent.
setInterceptDrags
Fields
enabled: boolImplementations