pub struct ProfileSnapshotParams {
pub snapshot_id: SnapshotId,
pub min_repeat_count: Option<i64>,
pub min_duration: Option<f64>,
pub clip_rect: Option<Rect>,
}Fields
snapshot_id: SnapshotIdThe id of the layer snapshot.
min_repeat_count: Option<i64>The maximum number of times to replay the snapshot (1, if not specified).
min_duration: Option<f64>The minimum duration (in seconds) to replay the snapshot.
clip_rect: Option<Rect>The clip rectangle to apply when replaying the snapshot.
Implementations
Sourceimpl ProfileSnapshotParams
impl ProfileSnapshotParams
pub fn new(snapshot_id: impl Into<SnapshotId>) -> Self