Module commands

Module commands 

Structs

Clear
Clears the log. clear
ClearParams
Clears the log. clear
Disable
Disables log domain, prevents further log entries from being reported to the client. disable
DisableParams
Disables log domain, prevents further log entries from being reported to the client. disable
Enable
Enables log domain, sends the entries collected so far to the client by means of the entryAdded notification. enable
EnableParams
Enables log domain, sends the entries collected so far to the client by means of the entryAdded notification. enable
StartViolationsReport
start violation reporting. startViolationsReport
StartViolationsReportParams
start violation reporting. startViolationsReport
StopViolationsReport
Stop violation reporting. stopViolationsReport
StopViolationsReportParams
Stop violation reporting. stopViolationsReport

Enums

ClearMethod
DisableMethod
EnableMethod
LogCommands
StartViolationsReportMethod
StopViolationsReportMethod