pub struct PlayerCreated {
pub method: PlayerCreatedMethod,
pub params: PlayerCreatedParams,
}Expand description
Called whenever a player is created, or when a new agent joins and receives a list of active players. If an agent is restored, it will receive one event for each active player. playerCreated
Fields
method: PlayerCreatedMethodparams: PlayerCreatedParamsImplementations
Sourceimpl PlayerCreated
impl PlayerCreated
pub const IDENTIFIER: &'static str = "Media.playerCreated"
pub fn identifier(&self) -> &'static str