Module commands

Module commands 

Structs

ForciblyPurgeJavaScriptMemory
Simulate OomIntervention by purging V8 memory. forciblyPurgeJavaScriptMemory
ForciblyPurgeJavaScriptMemoryParams
Simulate OomIntervention by purging V8 memory. forciblyPurgeJavaScriptMemory
GetAllTimeSamplingProfile
Retrieve native memory allocations profile collected since renderer process startup. getAllTimeSamplingProfile
GetAllTimeSamplingProfileParams
Retrieve native memory allocations profile collected since renderer process startup. getAllTimeSamplingProfile
GetBrowserSamplingProfile
Retrieve native memory allocations profile collected since browser process startup. getBrowserSamplingProfile
GetBrowserSamplingProfileParams
Retrieve native memory allocations profile collected since browser process startup. getBrowserSamplingProfile
GetDomCounters
Retruns current DOM object counters. getDOMCounters
GetDomCountersForLeakDetection
Retruns DOM object counters after preparing renderer for leak detection. getDOMCountersForLeakDetection
GetDomCountersForLeakDetectionParams
Retruns DOM object counters after preparing renderer for leak detection. getDOMCountersForLeakDetection
GetDomCountersParams
Retruns current DOM object counters. getDOMCounters
GetSamplingProfile
Retrieve native memory allocations profile collected since last startSampling call. getSamplingProfile
GetSamplingProfileParams
Retrieve native memory allocations profile collected since last startSampling call. getSamplingProfile
PrepareForLeakDetection
Prepares for leak detection by terminating workers, stopping spellcheckers, dropping non-essential internal caches, running garbage collections, etc. prepareForLeakDetection
PrepareForLeakDetectionParams
Prepares for leak detection by terminating workers, stopping spellcheckers, dropping non-essential internal caches, running garbage collections, etc. prepareForLeakDetection
SetPressureNotificationsSuppressed
Enable/disable suppressing memory pressure notifications in all processes. setPressureNotificationsSuppressed
SetPressureNotificationsSuppressedParams
Enable/disable suppressing memory pressure notifications in all processes. setPressureNotificationsSuppressed
SimulatePressureNotification
Simulate a memory pressure notification in all processes. simulatePressureNotification
SimulatePressureNotificationParams
Simulate a memory pressure notification in all processes. simulatePressureNotification
StartSampling
Start collecting native memory profile. startSampling
StartSamplingParams
Start collecting native memory profile. startSampling
StopSampling
Stop collecting native memory profile. stopSampling
StopSamplingParams
Stop collecting native memory profile. stopSampling

Enums

ForciblyPurgeJavaScriptMemoryMethod
GetAllTimeSamplingProfileMethod
GetBrowserSamplingProfileMethod
GetDomCountersForLeakDetectionMethod
GetDomCountersMethod
GetSamplingProfileMethod
MemoryCommands
PrepareForLeakDetectionMethod
SetPressureNotificationsSuppressedMethod
SimulatePressureNotificationMethod
StartSamplingMethod
StopSamplingMethod