Configures storing response bodies outside of renderer, so that these survive
a cross-process navigation.
If maxTotalBufferSize is not set, durable messages are disabled.
configureDurableMessages
Configures storing response bodies outside of renderer, so that these survive
a cross-process navigation.
If maxTotalBufferSize is not set, durable messages are disabled.
configureDurableMessages
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated
Network.emulateNetworkConditions this method does not affect navigator state. Use Network.overrideNetworkState to
explicitly modify navigator behavior.
emulateNetworkConditionsByRule
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated
Network.emulateNetworkConditions this method does not affect navigator state. Use Network.overrideNetworkState to
explicitly modify navigator behavior.
emulateNetworkConditionsByRule
Enables tracking for the Reporting API, events generated by the Reporting API will now be delivered to the client.
Enabling triggers ‘reportingApiReportAdded’ for all existing reports.
enableReportingApi
Enables tracking for the Reporting API, events generated by the Reporting API will now be delivered to the client.
Enabling triggers ‘reportingApiReportAdded’ for all existing reports.
enableReportingApi
Returns all browser cookies for the current URL. Depending on the backend support, will return
detailed cookie information in the cookies field.
getCookies
Returns all browser cookies for the current URL. Depending on the backend support, will return
detailed cookie information in the cookies field.
getCookies
This method sends a new XMLHttpRequest which is identical to the original one. The following
parameters should be identical: method, url, async, request body, extra headers, withCredentials
attribute, user, password.
replayXHR
This method sends a new XMLHttpRequest which is identical to the original one. The following
parameters should be identical: method, url, async, request body, extra headers, withCredentials
attribute, user, password.
replayXHR
Enables streaming of the response for the given requestId.
If enabled, the dataReceived event contains the data that was received during streaming.
streamResourceContent
Enables streaming of the response for the given requestId.
If enabled, the dataReceived event contains the data that was received during streaming.
streamResourceContent
Returns a handle to the stream representing the response body. Note that after this command,
the intercepted request can’t be continued as is – you either need to cancel it or to provide
the response body. The stream only supports sequential read, IO.read will fail if the position
is specified.
takeResponseBodyForInterceptionAsStream
Returns a handle to the stream representing the response body. Note that after this command,
the intercepted request can’t be continued as is – you either need to cancel it or to provide
the response body. The stream only supports sequential read, IO.read will fail if the position
is specified.
takeResponseBodyForInterceptionAsStream