EmulateNetworkConditionsByRuleParams

Struct EmulateNetworkConditionsByRuleParams 

pub struct EmulateNetworkConditionsByRuleParams {
    pub offline: bool,
    pub matched_network_conditions: Vec<NetworkConditions>,
}
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect navigator state. Use Network.overrideNetworkState to explicitly modify navigator behavior. emulateNetworkConditionsByRule

Fields

offline: bool

True to emulate internet disconnection.

matched_network_conditions: Vec<NetworkConditions>

Configure conditions for matching requests. If multiple entries match a request, the first entry wins. Global conditions can be configured by leaving the urlPattern for the conditions empty. These global conditions are also applied for throttling of p2p connections.

Implementations

Source

impl EmulateNetworkConditionsByRuleParams

pub fn new( offline: impl Into<bool>, matched_network_conditions: Vec<NetworkConditions>, ) -> Self