EnableParams

Struct EnableParams 

pub struct EnableParams {
    pub max_total_buffer_size: Option<i64>,
    pub max_resource_buffer_size: Option<i64>,
    pub max_post_data_size: Option<i64>,
    pub report_direct_socket_traffic: Option<bool>,
    pub enable_durable_messages: Option<bool>,
}
Enables network tracking, network events will now be delivered to the client. enable

Fields

max_total_buffer_size: Option<i64>

Buffer size in bytes to use when preserving network payloads (XHRs, etc). This is the maximum number of bytes that will be collected by this DevTools session.

max_resource_buffer_size: Option<i64>

Per-resource buffer size in bytes to use when preserving network payloads (XHRs, etc).

max_post_data_size: Option<i64>

Longest post body size (in bytes) that would be included in requestWillBeSent notification

report_direct_socket_traffic: Option<bool>

Whether DirectSocket chunk send/receive events should be reported.

enable_durable_messages: Option<bool>

Enable storing response bodies outside of renderer, so that these survive a cross-process navigation. Requires maxTotalBufferSize to be set. Currently defaults to false. This field is being deprecated in favor of the dedicated configureDurableMessages command, due to the possibility of deadlocks when awaiting Network.enable before issuing Runtime.runIfWaitingForDebugger.