pub struct GetResponseBodyForInterceptionParams {
pub interception_id: InterceptionId,
}Expand description
Returns content served for the given currently intercepted request. getResponseBodyForInterception
Fields
interception_id: InterceptionIdIdentifier for the intercepted request to get body for.
Implementations
Sourceimpl GetResponseBodyForInterceptionParams
impl GetResponseBodyForInterceptionParams
pub fn new(interception_id: impl Into<InterceptionId>) -> Self