pub struct SetAttachDebugStackParams {
pub enabled: bool,
}Expand description
Specifies whether to attach a page script stack id in requests setAttachDebugStack
Fields
enabled: boolWhether to attach a page script stack for debugging purpose.
Implementations