pub struct StreamResourceContent {
pub method: StreamResourceContentMethod,
pub params: StreamResourceContentParams,
}Expand description
Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming. streamResourceContent
Fields
method: StreamResourceContentMethodparams: StreamResourceContentParamsImplementations
Sourceimpl StreamResourceContent
impl StreamResourceContent
pub fn builder() -> StreamResourceContentBuilder
Sourceimpl StreamResourceContent
impl StreamResourceContent
pub const IDENTIFIER: &'static str = "Network.streamResourceContent"
pub fn identifier(&self) -> &'static str