pub struct StreamResourceContentParams {
pub request_id: RequestId,
}Expand description
Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming. streamResourceContent
Fields
request_id: RequestIdIdentifier of the request to stream.
Implementations