pub struct TakeResponseBodyForInterceptionAsStream {
pub method: TakeResponseBodyForInterceptionAsStreamMethod,
pub params: TakeResponseBodyForInterceptionAsStreamParams,
}Expand description
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. takeResponseBodyForInterceptionAsStream
Fields
method: TakeResponseBodyForInterceptionAsStreamMethodparams: TakeResponseBodyForInterceptionAsStreamParamsImplementations
Sourceimpl TakeResponseBodyForInterceptionAsStream
impl TakeResponseBodyForInterceptionAsStream
pub const IDENTIFIER: &'static str = "Network.takeResponseBodyForInterceptionAsStream"
pub fn identifier(&self) -> &'static str