Module events

Structs

DataReceived
Fired when data chunk was received over the network. dataReceived
DataReceivedParams
Fired when data chunk was received over the network. dataReceived
DeviceBoundSessionEventOccurred
Triggered when a device bound session event occurs. deviceBoundSessionEventOccurred
DeviceBoundSessionEventOccurredParams
Triggered when a device bound session event occurs. deviceBoundSessionEventOccurred
DeviceBoundSessionsAdded
Triggered when the initial set of device bound sessions is added. deviceBoundSessionsAdded
DeviceBoundSessionsAddedParams
Triggered when the initial set of device bound sessions is added. deviceBoundSessionsAdded
DirectTcpSocketAborted
Fired when direct_socket.TCPSocket is aborted. directTCPSocketAborted
DirectTcpSocketAbortedParams
Fired when direct_socket.TCPSocket is aborted. directTCPSocketAborted
DirectTcpSocketChunkReceived
Fired when data is received from tcp direct socket stream. directTCPSocketChunkReceived
DirectTcpSocketChunkReceivedParams
Fired when data is received from tcp direct socket stream. directTCPSocketChunkReceived
DirectTcpSocketChunkSent
Fired when data is sent to tcp direct socket stream. directTCPSocketChunkSent
DirectTcpSocketChunkSentParams
Fired when data is sent to tcp direct socket stream. directTCPSocketChunkSent
DirectTcpSocketClosed
Fired when direct_socket.TCPSocket is closed. directTCPSocketClosed
DirectTcpSocketClosedParams
Fired when direct_socket.TCPSocket is closed. directTCPSocketClosed
DirectTcpSocketCreated
Fired upon direct_socket.TCPSocket creation. directTCPSocketCreated
DirectTcpSocketCreatedParams
Fired upon direct_socket.TCPSocket creation. directTCPSocketCreated
DirectTcpSocketOpened
Fired when direct_socket.TCPSocket connection is opened. directTCPSocketOpened
DirectTcpSocketOpenedParams
Fired when direct_socket.TCPSocket connection is opened. directTCPSocketOpened
DirectUdpSocketAborted
Fired when direct_socket.UDPSocket is aborted. directUDPSocketAborted
DirectUdpSocketAbortedParams
Fired when direct_socket.UDPSocket is aborted. directUDPSocketAborted
DirectUdpSocketChunkReceived
Fired when message is received from udp direct socket stream. directUDPSocketChunkReceived
DirectUdpSocketChunkReceivedParams
Fired when message is received from udp direct socket stream. directUDPSocketChunkReceived
DirectUdpSocketChunkSent
Fired when message is sent to udp direct socket stream. directUDPSocketChunkSent
DirectUdpSocketChunkSentParams
Fired when message is sent to udp direct socket stream. directUDPSocketChunkSent
DirectUdpSocketClosed
Fired when direct_socket.UDPSocket is closed. directUDPSocketClosed
DirectUdpSocketClosedParams
Fired when direct_socket.UDPSocket is closed. directUDPSocketClosed
DirectUdpSocketCreated
Fired upon direct_socket.UDPSocket creation. directUDPSocketCreated
DirectUdpSocketCreatedParams
Fired upon direct_socket.UDPSocket creation. directUDPSocketCreated
DirectUdpSocketJoinedMulticastGroup
DirectUdpSocketJoinedMulticastGroupParams
DirectUdpSocketLeftMulticastGroup
DirectUdpSocketLeftMulticastGroupParams
DirectUdpSocketOpened
Fired when direct_socket.UDPSocket connection is opened. directUDPSocketOpened
DirectUdpSocketOpenedParams
Fired when direct_socket.UDPSocket connection is opened. directUDPSocketOpened
EventSourceMessageReceived
Fired when EventSource message is received. eventSourceMessageReceived
EventSourceMessageReceivedParams
Fired when EventSource message is received. eventSourceMessageReceived
LoadingFailed
Fired when HTTP request has failed to load. loadingFailed
LoadingFailedParams
Fired when HTTP request has failed to load. loadingFailed
LoadingFinished
Fired when HTTP request has finished loading. loadingFinished
LoadingFinishedParams
Fired when HTTP request has finished loading. loadingFinished
PolicyUpdated
Fired once security policy has been updated. policyUpdated
PolicyUpdatedParams
Fired once security policy has been updated. policyUpdated
ReportingApiEndpointsChangedForOrigin
ReportingApiEndpointsChangedForOriginParams
ReportingApiReportAdded
Is sent whenever a new report is added. And after ‘enableReportingApi’ for all existing reports. reportingApiReportAdded
ReportingApiReportAddedParams
Is sent whenever a new report is added. And after ‘enableReportingApi’ for all existing reports. reportingApiReportAdded
ReportingApiReportUpdated
ReportingApiReportUpdatedParams
RequestServedFromCache
Fired if request ended up loading from cache. requestServedFromCache
RequestServedFromCacheParams
Fired if request ended up loading from cache. requestServedFromCache
RequestWillBeSent
Fired when page is about to send HTTP request. requestWillBeSent
RequestWillBeSentExtraInfo
Fired when additional information about a requestWillBeSent event is available from the network stack. Not every requestWillBeSent event will have an additional requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent or requestWillBeSentExtraInfo will be fired first for the same request. requestWillBeSentExtraInfo
RequestWillBeSentExtraInfoParams
Fired when additional information about a requestWillBeSent event is available from the network stack. Not every requestWillBeSent event will have an additional requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent or requestWillBeSentExtraInfo will be fired first for the same request. requestWillBeSentExtraInfo
RequestWillBeSentParams
Fired when page is about to send HTTP request. requestWillBeSent
ResourceChangedPriority
Fired when resource loading priority is changed resourceChangedPriority
ResourceChangedPriorityParams
Fired when resource loading priority is changed resourceChangedPriority
ResponseReceived
Fired when HTTP response is available. responseReceived
ResponseReceivedEarlyHints
Fired when 103 Early Hints headers is received in addition to the common response. Not every responseReceived event will have an responseReceivedEarlyHints fired. Only one responseReceivedEarlyHints may be fired for eached responseReceived event. responseReceivedEarlyHints
ResponseReceivedEarlyHintsParams
Fired when 103 Early Hints headers is received in addition to the common response. Not every responseReceived event will have an responseReceivedEarlyHints fired. Only one responseReceivedEarlyHints may be fired for eached responseReceived event. responseReceivedEarlyHints
ResponseReceivedExtraInfo
Fired when additional information about a responseReceived event is available from the network stack. Not every responseReceived event will have an additional responseReceivedExtraInfo for it, and responseReceivedExtraInfo may be fired before or after responseReceived. responseReceivedExtraInfo
ResponseReceivedExtraInfoParams
Fired when additional information about a responseReceived event is available from the network stack. Not every responseReceived event will have an additional responseReceivedExtraInfo for it, and responseReceivedExtraInfo may be fired before or after responseReceived. responseReceivedExtraInfo
ResponseReceivedParams
Fired when HTTP response is available. responseReceived
SignedExchangeReceived
Fired when a signed exchange was received over the network signedExchangeReceived
SignedExchangeReceivedParams
Fired when a signed exchange was received over the network signedExchangeReceived
TrustTokenOperationDone
Fired exactly once for each Trust Token operation. Depending on the type of the operation and whether the operation succeeded or failed, the event is fired before the corresponding request was sent or after the response was received. trustTokenOperationDone
TrustTokenOperationDoneParams
Fired exactly once for each Trust Token operation. Depending on the type of the operation and whether the operation succeeded or failed, the event is fired before the corresponding request was sent or after the response was received. trustTokenOperationDone
WebSocketClosed
Fired when WebSocket is closed. webSocketClosed
WebSocketClosedParams
Fired when WebSocket is closed. webSocketClosed
WebSocketCreated
Fired upon WebSocket creation. webSocketCreated
WebSocketCreatedParams
Fired upon WebSocket creation. webSocketCreated
WebSocketFrameError
Fired when WebSocket message error occurs. webSocketFrameError
WebSocketFrameErrorParams
Fired when WebSocket message error occurs. webSocketFrameError
WebSocketFrameReceived
Fired when WebSocket message is received. webSocketFrameReceived
WebSocketFrameReceivedParams
Fired when WebSocket message is received. webSocketFrameReceived
WebSocketFrameSent
Fired when WebSocket message is sent. webSocketFrameSent
WebSocketFrameSentParams
Fired when WebSocket message is sent. webSocketFrameSent
WebSocketHandshakeResponseReceived
Fired when WebSocket handshake response becomes available. webSocketHandshakeResponseReceived
WebSocketHandshakeResponseReceivedParams
Fired when WebSocket handshake response becomes available. webSocketHandshakeResponseReceived
WebSocketWillSendHandshakeRequest
Fired when WebSocket is about to initiate handshake. webSocketWillSendHandshakeRequest
WebSocketWillSendHandshakeRequestParams
Fired when WebSocket is about to initiate handshake. webSocketWillSendHandshakeRequest
WebTransportClosed
Fired when WebTransport is disposed. webTransportClosed
WebTransportClosedParams
Fired when WebTransport is disposed. webTransportClosed
WebTransportConnectionEstablished
Fired when WebTransport handshake is finished. webTransportConnectionEstablished
WebTransportConnectionEstablishedParams
Fired when WebTransport handshake is finished. webTransportConnectionEstablished
WebTransportCreated
Fired upon WebTransport creation. webTransportCreated
WebTransportCreatedParams
Fired upon WebTransport creation. webTransportCreated

Enums

DataReceivedMethod
DeviceBoundSessionEventOccurredMethod
DeviceBoundSessionsAddedMethod
DirectTcpSocketAbortedMethod
DirectTcpSocketChunkReceivedMethod
DirectTcpSocketChunkSentMethod
DirectTcpSocketClosedMethod
DirectTcpSocketCreatedMethod
DirectTcpSocketOpenedMethod
DirectUdpSocketAbortedMethod
DirectUdpSocketChunkReceivedMethod
DirectUdpSocketChunkSentMethod
DirectUdpSocketClosedMethod
DirectUdpSocketCreatedMethod
DirectUdpSocketJoinedMulticastGroupMethod
DirectUdpSocketLeftMulticastGroupMethod
DirectUdpSocketOpenedMethod
EventSourceMessageReceivedMethod
LoadingFailedMethod
LoadingFinishedMethod
NetworkEvents
PolicyUpdatedMethod
ReportingApiEndpointsChangedForOriginMethod
ReportingApiReportAddedMethod
ReportingApiReportUpdatedMethod
RequestServedFromCacheMethod
RequestWillBeSentExtraInfoMethod
RequestWillBeSentMethod
ResourceChangedPriorityMethod
ResponseReceivedEarlyHintsMethod
ResponseReceivedExtraInfoMethod
ResponseReceivedMethod
SignedExchangeReceivedMethod
TrustTokenOperationDoneMethod
TrustTokenOperationDoneStatus
Detailed success or error status of the operation. ‘AlreadyExists’ also signifies a successful operation, as the result of the operation already exists und thus, the operation was abort preemptively (e.g. a cache hit).
WebSocketClosedMethod
WebSocketCreatedMethod
WebSocketFrameErrorMethod
WebSocketFrameReceivedMethod
WebSocketFrameSentMethod
WebSocketHandshakeResponseReceivedMethod
WebSocketWillSendHandshakeRequestMethod
WebTransportClosedMethod
WebTransportConnectionEstablishedMethod
WebTransportCreatedMethod