pub struct DeviceBoundSessionEventOccurredParams {
pub event_id: DeviceBoundSessionEventId,
pub site: String,
pub succeeded: bool,
pub session_id: Option<String>,
pub creation_event_details: Option<CreationEventDetails>,
pub refresh_event_details: Option<RefreshEventDetails>,
pub termination_event_details: Option<TerminationEventDetails>,
pub challenge_event_details: Option<ChallengeEventDetails>,
}Expand description
Triggered when a device bound session event occurs. deviceBoundSessionEventOccurred
Fields
event_id: DeviceBoundSessionEventIdA unique identifier for this session event.
site: StringThe site this session event is associated with.
succeeded: boolWhether this event was considered successful.
session_id: Option<String>The session ID this event is associated with. May not be populated for failed events.
creation_event_details: Option<CreationEventDetails>The below are the different session event type details. Exactly one is populated.
refresh_event_details: Option<RefreshEventDetails>termination_event_details: Option<TerminationEventDetails>challenge_event_details: Option<ChallengeEventDetails>Trait Implementations
Sourceimpl Clone for DeviceBoundSessionEventOccurredParams
impl Clone for DeviceBoundSessionEventOccurredParams
Sourcefn clone(&self) -> DeviceBoundSessionEventOccurredParams
fn clone(&self) -> DeviceBoundSessionEventOccurredParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DeviceBoundSessionEventOccurredParams
impl<'de> Deserialize<'de> for DeviceBoundSessionEventOccurredParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DeviceBoundSessionEventOccurredParams
impl PartialEq for DeviceBoundSessionEventOccurredParams
Sourcefn eq(&self, other: &DeviceBoundSessionEventOccurredParams) -> bool
fn eq(&self, other: &DeviceBoundSessionEventOccurredParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceBoundSessionEventOccurredParams