pub struct DirectTcpSocketChunkSentParams {
pub identifier: RequestId,
pub data: Binary,
pub timestamp: MonotonicTime,
}Expand description
Fired when data is sent to tcp direct socket stream. directTCPSocketChunkSent
Fields
identifier: RequestIddata: Binarytimestamp: MonotonicTimeTrait Implementations
Sourceimpl Clone for DirectTcpSocketChunkSentParams
impl Clone for DirectTcpSocketChunkSentParams
Sourcefn clone(&self) -> DirectTcpSocketChunkSentParams
fn clone(&self) -> DirectTcpSocketChunkSentParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DirectTcpSocketChunkSentParams
impl<'de> Deserialize<'de> for DirectTcpSocketChunkSentParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DirectTcpSocketChunkSentParams
impl PartialEq for DirectTcpSocketChunkSentParams
Sourcefn eq(&self, other: &DirectTcpSocketChunkSentParams) -> bool
fn eq(&self, other: &DirectTcpSocketChunkSentParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DirectTcpSocketChunkSentParams