pub struct DirectUdpSocketChunkReceivedParams {
pub identifier: RequestId,
pub message: DirectUdpMessage,
pub timestamp: MonotonicTime,
}Expand description
Fired when message is received from udp direct socket stream. directUDPSocketChunkReceived
Fields
identifier: RequestIdmessage: DirectUdpMessagetimestamp: MonotonicTimeTrait Implementations
Sourceimpl Clone for DirectUdpSocketChunkReceivedParams
impl Clone for DirectUdpSocketChunkReceivedParams
Sourcefn clone(&self) -> DirectUdpSocketChunkReceivedParams
fn clone(&self) -> DirectUdpSocketChunkReceivedParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DirectUdpSocketChunkReceivedParams
impl<'de> Deserialize<'de> for DirectUdpSocketChunkReceivedParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DirectUdpSocketChunkReceivedParams
impl PartialEq for DirectUdpSocketChunkReceivedParams
Sourcefn eq(&self, other: &DirectUdpSocketChunkReceivedParams) -> bool
fn eq(&self, other: &DirectUdpSocketChunkReceivedParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DirectUdpSocketChunkReceivedParams