pub struct DirectUdpSocketChunkSentParams {
pub identifier: RequestId,
pub message: DirectUdpMessage,
pub timestamp: MonotonicTime,
}Expand description
Fired when message is sent to udp direct socket stream. directUDPSocketChunkSent
Fields
identifier: RequestIdmessage: DirectUdpMessagetimestamp: MonotonicTimeTrait Implementations
Sourceimpl Clone for DirectUdpSocketChunkSentParams
impl Clone for DirectUdpSocketChunkSentParams
Sourcefn clone(&self) -> DirectUdpSocketChunkSentParams
fn clone(&self) -> DirectUdpSocketChunkSentParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DirectUdpSocketChunkSentParams
impl<'de> Deserialize<'de> for DirectUdpSocketChunkSentParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DirectUdpSocketChunkSentParams
impl PartialEq for DirectUdpSocketChunkSentParams
Sourcefn eq(&self, other: &DirectUdpSocketChunkSentParams) -> bool
fn eq(&self, other: &DirectUdpSocketChunkSentParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DirectUdpSocketChunkSentParams