RequestWillBeSentExtraInfo

Struct RequestWillBeSentExtraInfo 

pub struct RequestWillBeSentExtraInfo {
    pub method: RequestWillBeSentExtraInfoMethod,
    pub params: RequestWillBeSentExtraInfoParams,
}
Fired when additional information about a requestWillBeSent event is available from the network stack. Not every requestWillBeSent event will have an additional requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent or requestWillBeSentExtraInfo will be fired first for the same request. requestWillBeSentExtraInfo

Fields

method: RequestWillBeSentExtraInfoMethodparams: RequestWillBeSentExtraInfoParams

Implementations

Source

impl RequestWillBeSentExtraInfo

pub const IDENTIFIER: &'static str = "Network.requestWillBeSentExtraInfo"

pub fn identifier(&self) -> &'static str