pub struct RequestWillBeSentParams {Show 13 fields
pub request_id: RequestId,
pub loader_id: Box<LoaderId>,
pub document_url: String,
pub request: Request,
pub timestamp: MonotonicTime,
pub wall_time: TimeSinceEpoch,
pub initiator: Initiator,
pub redirect_has_extra_info: bool,
pub redirect_response: Option<Response>,
pub type: Option<ResourceType>,
pub frame_id: Option<FrameId>,
pub has_user_gesture: Option<bool>,
pub render_blocking_behavior: Option<RenderBlockingBehavior>,
}Expand description
Fired when page is about to send HTTP request. requestWillBeSent
Fields
request_id: RequestIdRequest identifier.
loader_id: Box<LoaderId>Loader identifier. Empty string if the request is fetched from worker.
document_url: StringURL of the document this request is loaded for.
request: RequestRequest data.
timestamp: MonotonicTimeTimestamp.
wall_time: TimeSinceEpochTimestamp.
initiator: InitiatorRequest initiator.
redirect_has_extra_info: boolIn the case that redirectResponse is populated, this flag indicates whether requestWillBeSentExtraInfo and responseReceivedExtraInfo events will be or were emitted for the request which was just redirected.
redirect_response: Option<Response>Redirect response data.
type: Option<ResourceType>Type of this resource.
frame_id: Option<FrameId>Frame identifier.
has_user_gesture: Option<bool>Whether the request is initiated by a user gesture. Defaults to false.
render_blocking_behavior: Option<RenderBlockingBehavior>The render blocking behavior of the request.