pub struct ResponseReceivedEarlyHintsParams {
pub request_id: RequestId,
pub headers: Headers,
}Expand description
Fired when 103 Early Hints headers is received in addition to the common response. Not every responseReceived event will have an responseReceivedEarlyHints fired. Only one responseReceivedEarlyHints may be fired for eached responseReceived event. responseReceivedEarlyHints
Fields
request_id: RequestIdRequest identifier. Used to match this information to another responseReceived event.
headers: HeadersRaw response headers as they were received over the wire.
Duplicate headers in the response are represented as a single key with their values
concatentated using \n as the separator.
See also headersText that contains verbatim text for HTTP/1.*.