ResponseReceivedExtraInfoParams

Struct ResponseReceivedExtraInfoParams 

pub struct ResponseReceivedExtraInfoParams {
    pub request_id: RequestId,
    pub blocked_cookies: Vec<BlockedSetCookieWithReason>,
    pub headers: Headers,
    pub resource_ip_address_space: IpAddressSpace,
    pub status_code: i64,
    pub headers_text: Option<String>,
    pub cookie_partition_key: Option<CookiePartitionKey>,
    pub cookie_partition_key_opaque: Option<bool>,
    pub exempted_cookies: Option<Vec<ExemptedSetCookieWithReason>>,
}
Fired when additional information about a responseReceived event is available from the network stack. Not every responseReceived event will have an additional responseReceivedExtraInfo for it, and responseReceivedExtraInfo may be fired before or after responseReceived. responseReceivedExtraInfo

Fields

request_id: RequestId

Request identifier. Used to match this information to another responseReceived event.

blocked_cookies: Vec<BlockedSetCookieWithReason>

A list of cookies which were not stored from the response along with the corresponding reasons for blocking. The cookies here may not be valid due to syntax errors, which are represented by the invalid cookie line string instead of a proper cookie.

headers: Headers

Raw response headers as they were received over the wire. Duplicate headers in the response are represented as a single key with their values concatentated using \n as the separator. See also headersText that contains verbatim text for HTTP/1.*.

resource_ip_address_space: IpAddressSpace

The IP address space of the resource. The address space can only be determined once the transport established the connection, so we can’t send it in requestWillBeSentExtraInfo.

status_code: i64

The status code of the response. This is useful in cases the request failed and no responseReceived event is triggered, which is the case for, e.g., CORS errors. This is also the correct status code for cached requests, where the status in responseReceived is a 200 and this will be 304.

headers_text: Option<String>

Raw response header text as it was received over the wire. The raw text may not always be available, such as in the case of HTTP/2 or QUIC.

cookie_partition_key: Option<CookiePartitionKey>

The cookie partition key that will be used to store partitioned cookies set in this response. Only sent when partitioned cookies are enabled.

cookie_partition_key_opaque: Option<bool>

True if partitioned cookies are enabled, but the partition key is not serializable to string.

exempted_cookies: Option<Vec<ExemptedSetCookieWithReason>>

A list of cookies which should have been blocked by 3PCD but are exempted and stored from the response with the corresponding reason.