pub struct ResponseReceivedParams {
pub request_id: RequestId,
pub loader_id: Box<LoaderId>,
pub timestamp: MonotonicTime,
pub type: ResourceType,
pub response: Response,
pub has_extra_info: bool,
pub frame_id: Option<FrameId>,
}Expand description
Fired when HTTP response is available. responseReceived
Fields
request_id: RequestIdRequest identifier.
loader_id: Box<LoaderId>Loader identifier. Empty string if the request is fetched from worker.
timestamp: MonotonicTimeTimestamp.
type: ResourceTypeResource type.
response: ResponseResponse data.
has_extra_info: boolIndicates whether requestWillBeSentExtraInfo and responseReceivedExtraInfo events will be or were emitted for this request.
frame_id: Option<FrameId>Frame identifier.