TrustTokenOperationDone

Struct TrustTokenOperationDone 

pub struct TrustTokenOperationDone {
    pub method: TrustTokenOperationDoneMethod,
    pub params: TrustTokenOperationDoneParams,
}
Fired exactly once for each Trust Token operation. Depending on the type of the operation and whether the operation succeeded or failed, the event is fired before the corresponding request was sent or after the response was received. trustTokenOperationDone

Fields

method: TrustTokenOperationDoneMethodparams: TrustTokenOperationDoneParams

Implementations

Source

impl TrustTokenOperationDone

pub const IDENTIFIER: &'static str = "Network.trustTokenOperationDone"

pub fn identifier(&self) -> &'static str