TrustTokenOperationDoneParams

Struct TrustTokenOperationDoneParams 

pub struct TrustTokenOperationDoneParams {
    pub status: TrustTokenOperationDoneStatus,
    pub type: TrustTokenOperationType,
    pub request_id: RequestId,
    pub top_level_origin: Option<String>,
    pub issuer_origin: Option<String>,
    pub issued_token_count: Option<i64>,
}
Fired exactly once for each Trust Token operation. Depending on the type of the operation and whether the operation succeeded or failed, the event is fired before the corresponding request was sent or after the response was received. trustTokenOperationDone

Fields

status: TrustTokenOperationDoneStatus

Detailed success or error status of the operation. ‘AlreadyExists’ also signifies a successful operation, as the result of the operation already exists und thus, the operation was abort preemptively (e.g. a cache hit).

type: TrustTokenOperationTyperequest_id: RequestIdtop_level_origin: Option<String>

Top level origin. The context in which the operation was attempted.

issuer_origin: Option<String>

Origin of the issuer in case of a “Issuance” or “Redemption” operation.

issued_token_count: Option<i64>

The number of obtained Trust Tokens on a successful “Issuance” operation.