Module commands

Module commands 

Structs

Disable
Disables domain notifications. disable
DisableParams
Disables domain notifications. disable
Enable
Enables domain notifications. enable
EnableParams
Enables domain notifications. enable
GetGridHighlightObjectsForTest
For Persistent Grid testing. getGridHighlightObjectsForTest
GetGridHighlightObjectsForTestParams
For Persistent Grid testing. getGridHighlightObjectsForTest
GetHighlightObjectForTest
For testing. getHighlightObjectForTest
GetHighlightObjectForTestParams
For testing. getHighlightObjectForTest
GetSourceOrderHighlightObjectForTest
For Source Order Viewer testing. getSourceOrderHighlightObjectForTest
GetSourceOrderHighlightObjectForTestParams
For Source Order Viewer testing. getSourceOrderHighlightObjectForTest
HideHighlight
Hides any highlight. hideHighlight
HideHighlightParams
Hides any highlight. hideHighlight
HighlightNode
Highlights DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified. highlightNode
HighlightNodeParams
Highlights DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified. highlightNode
HighlightQuad
Highlights given quad. Coordinates are absolute with respect to the main frame viewport. highlightQuad
HighlightQuadParams
Highlights given quad. Coordinates are absolute with respect to the main frame viewport. highlightQuad
HighlightRect
Highlights given rectangle. Coordinates are absolute with respect to the main frame viewport. Issue: the method does not handle device pixel ratio (DPR) correctly. The coordinates currently have to be adjusted by the client if DPR is not 1 (see crbug.com/437807128). highlightRect
HighlightRectParams
Highlights given rectangle. Coordinates are absolute with respect to the main frame viewport. Issue: the method does not handle device pixel ratio (DPR) correctly. The coordinates currently have to be adjusted by the client if DPR is not 1 (see crbug.com/437807128). highlightRect
HighlightSourceOrder
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified. highlightSourceOrder
HighlightSourceOrderParams
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified. highlightSourceOrder
SetInspectMode
Enters the ‘inspect’ mode. In this mode, elements that user is hovering over are highlighted. Backend then generates ‘inspectNodeRequested’ event upon element selection. setInspectMode
SetInspectModeParams
Enters the ‘inspect’ mode. In this mode, elements that user is hovering over are highlighted. Backend then generates ‘inspectNodeRequested’ event upon element selection. setInspectMode
SetPausedInDebuggerMessage
SetPausedInDebuggerMessageParams
SetShowAdHighlights
Highlights owner element of all frames detected to be ads. setShowAdHighlights
SetShowAdHighlightsParams
Highlights owner element of all frames detected to be ads. setShowAdHighlights
SetShowContainerQueryOverlays
SetShowContainerQueryOverlaysParams
SetShowDebugBorders
Requests that backend shows debug borders on layers setShowDebugBorders
SetShowDebugBordersParams
Requests that backend shows debug borders on layers setShowDebugBorders
SetShowFlexOverlays
SetShowFlexOverlaysParams
SetShowFpsCounter
Requests that backend shows the FPS counter setShowFPSCounter
SetShowFpsCounterParams
Requests that backend shows the FPS counter setShowFPSCounter
SetShowGridOverlays
Highlight multiple elements with the CSS Grid overlay. setShowGridOverlays
SetShowGridOverlaysParams
Highlight multiple elements with the CSS Grid overlay. setShowGridOverlays
SetShowHinge
Add a dual screen device hinge setShowHinge
SetShowHingeParams
Add a dual screen device hinge setShowHinge
SetShowInspectedElementAnchor
SetShowInspectedElementAnchorParams
SetShowIsolatedElements
Show elements in isolation mode with overlays. setShowIsolatedElements
SetShowIsolatedElementsParams
Show elements in isolation mode with overlays. setShowIsolatedElements
SetShowLayoutShiftRegions
Requests that backend shows layout shift regions setShowLayoutShiftRegions
SetShowLayoutShiftRegionsParams
Requests that backend shows layout shift regions setShowLayoutShiftRegions
SetShowPaintRects
Requests that backend shows paint rectangles setShowPaintRects
SetShowPaintRectsParams
Requests that backend shows paint rectangles setShowPaintRects
SetShowScrollBottleneckRects
Requests that backend shows scroll bottleneck rects setShowScrollBottleneckRects
SetShowScrollBottleneckRectsParams
Requests that backend shows scroll bottleneck rects setShowScrollBottleneckRects
SetShowScrollSnapOverlays
SetShowScrollSnapOverlaysParams
SetShowViewportSizeOnResize
Paints viewport size upon main frame resize. setShowViewportSizeOnResize
SetShowViewportSizeOnResizeParams
Paints viewport size upon main frame resize. setShowViewportSizeOnResize
SetShowWindowControlsOverlay
Show Window Controls Overlay for PWA setShowWindowControlsOverlay
SetShowWindowControlsOverlayParams
Show Window Controls Overlay for PWA setShowWindowControlsOverlay

Enums

DisableMethod
EnableMethod
GetGridHighlightObjectsForTestMethod
GetHighlightObjectForTestMethod
GetSourceOrderHighlightObjectForTestMethod
HideHighlightMethod
HighlightNodeMethod
HighlightQuadMethod
HighlightRectMethod
HighlightSourceOrderMethod
OverlayCommands
SetInspectModeMethod
SetPausedInDebuggerMessageMethod
SetShowAdHighlightsMethod
SetShowContainerQueryOverlaysMethod
SetShowDebugBordersMethod
SetShowFlexOverlaysMethod
SetShowFpsCounterMethod
SetShowGridOverlaysMethod
SetShowHingeMethod
SetShowInspectedElementAnchorMethod
SetShowIsolatedElementsMethod
SetShowLayoutShiftRegionsMethod
SetShowPaintRectsMethod
SetShowScrollBottleneckRectsMethod
SetShowScrollSnapOverlaysMethod
SetShowViewportSizeOnResizeMethod
SetShowWindowControlsOverlayMethod