pub struct HighlightRect {
pub method: HighlightRectMethod,
pub params: HighlightRectParams,
}Expand description
Highlights given rectangle. Coordinates are absolute with respect to the main frame viewport. Issue: the method does not handle device pixel ratio (DPR) correctly. The coordinates currently have to be adjusted by the client if DPR is not 1 (see crbug.com/437807128). highlightRect
Fields
method: HighlightRectMethodparams: HighlightRectParamsImplementations
Sourceimpl HighlightRect
impl HighlightRect
pub fn builder() -> HighlightRectBuilder
Sourceimpl HighlightRect
impl HighlightRect
pub const IDENTIFIER: &'static str = "Overlay.highlightRect"
pub fn identifier(&self) -> &'static str