pub struct HighlightRectParams {
pub x: i64,
pub y: i64,
pub width: i64,
pub height: i64,
pub color: Option<Rgba>,
pub outline_color: Option<Rgba>,
}Expand description
Highlights given rectangle. Coordinates are absolute with respect to the main frame viewport. Issue: the method does not handle device pixel ratio (DPR) correctly. The coordinates currently have to be adjusted by the client if DPR is not 1 (see crbug.com/437807128). highlightRect
Fields
x: i64X coordinate
y: i64Y coordinate
width: i64Rectangle width
height: i64Rectangle height
color: Option<Rgba>The highlight fill color (default: transparent).
outline_color: Option<Rgba>The highlight outline color (default: transparent).
Implementations