HighlightSourceOrder

Struct HighlightSourceOrder 

pub struct HighlightSourceOrder {
    pub method: HighlightSourceOrderMethod,
    pub params: HighlightSourceOrderParams,
}
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified. highlightSourceOrder

Fields

method: HighlightSourceOrderMethodparams: HighlightSourceOrderParams

Implementations

Source

impl HighlightSourceOrder

Source

impl HighlightSourceOrder

pub const IDENTIFIER: &'static str = "Overlay.highlightSourceOrder"

pub fn identifier(&self) -> &'static str