Module events

Structs

InspectModeCanceled
Fired when user cancels the inspect mode. inspectModeCanceled
InspectModeCanceledParams
Fired when user cancels the inspect mode. inspectModeCanceled
InspectNodeRequested
Fired when the node should be inspected. This happens after call to setInspectMode or when user manually inspects an element. inspectNodeRequested
InspectNodeRequestedParams
Fired when the node should be inspected. This happens after call to setInspectMode or when user manually inspects an element. inspectNodeRequested
InspectPanelShowRequested
Fired when user asks to show the Inspect panel. inspectPanelShowRequested
InspectPanelShowRequestedParams
Fired when user asks to show the Inspect panel. inspectPanelShowRequested
InspectedElementWindowRestored
Fired when user asks to restore the Inspected Element floating window. inspectedElementWindowRestored
InspectedElementWindowRestoredParams
Fired when user asks to restore the Inspected Element floating window. inspectedElementWindowRestored
NodeHighlightRequested
Fired when the node should be highlighted. This happens after call to setInspectMode. nodeHighlightRequested
NodeHighlightRequestedParams
Fired when the node should be highlighted. This happens after call to setInspectMode. nodeHighlightRequested
ScreenshotRequested
Fired when user asks to capture screenshot of some area on the page. screenshotRequested
ScreenshotRequestedParams
Fired when user asks to capture screenshot of some area on the page. screenshotRequested

Enums

InspectModeCanceledMethod
InspectNodeRequestedMethod
InspectPanelShowRequestedMethod
InspectedElementWindowRestoredMethod
NodeHighlightRequestedMethod
OverlayEvents
ScreenshotRequestedMethod