pub struct CreateIsolatedWorldParams {
pub frame_id: Box<FrameId>,
pub world_name: Option<String>,
pub grant_univeral_access: Option<bool>,
}Expand description
Creates an isolated world for the given frame. createIsolatedWorld
Fields
frame_id: Box<FrameId>Id of the frame in which the isolated world should be created.
world_name: Option<String>An optional name which is reported in the Execution Context.
grant_univeral_access: Option<bool>Whether or not universal access should be granted to the isolated world. This is a powerful option, use with caution.
Implementations