pub struct GetAppManifest {
pub method: GetAppManifestMethod,
pub params: GetAppManifestParams,
}Expand description
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately. getAppManifest
Fields
method: GetAppManifestMethodparams: GetAppManifestParamsImplementations
Sourceimpl GetAppManifest
impl GetAppManifest
pub fn builder() -> GetAppManifestBuilder
Sourceimpl GetAppManifest
impl GetAppManifest
pub const IDENTIFIER: &'static str = "Page.getAppManifest"
pub fn identifier(&self) -> &'static str