ProduceCompilationCache

Struct ProduceCompilationCache 

pub struct ProduceCompilationCache {
    pub method: ProduceCompilationCacheMethod,
    pub params: ProduceCompilationCacheParams,
}
Requests backend to produce compilation cache for the specified scripts. scripts are appended to the list of scripts for which the cache would be produced. The list may be reset during page navigation. When script with a matching URL is encountered, the cache is optionally produced upon backend discretion, based on internal heuristics. See also: Page.compilationCacheProduced. produceCompilationCache

Fields

method: ProduceCompilationCacheMethodparams: ProduceCompilationCacheParams

Implementations

Source

impl ProduceCompilationCache

Source

impl ProduceCompilationCache

pub const IDENTIFIER: &'static str = "Page.produceCompilationCache"

pub fn identifier(&self) -> &'static str