pub struct SetInterceptFileChooserDialog {
pub method: SetInterceptFileChooserDialogMethod,
pub params: SetInterceptFileChooserDialogParams,
}Expand description
Intercept file chooser requests and transfer control to protocol clients.
When file chooser interception is enabled, native file chooser dialog is not shown.
Instead, a protocol event Page.fileChooserOpened is emitted.
setInterceptFileChooserDialog
Fields
method: SetInterceptFileChooserDialogMethodparams: SetInterceptFileChooserDialogParamsImplementations
Sourceimpl SetInterceptFileChooserDialog
impl SetInterceptFileChooserDialog
pub fn builder() -> SetInterceptFileChooserDialogBuilder
Sourceimpl SetInterceptFileChooserDialog
impl SetInterceptFileChooserDialog
pub const IDENTIFIER: &'static str = "Page.setInterceptFileChooserDialog"
pub fn identifier(&self) -> &'static str