pub struct SetWebLifecycleState {
pub method: SetWebLifecycleStateMethod,
pub params: SetWebLifecycleStateParams,
}Expand description
Tries to update the web lifecycle state of the page. It will transition the page to the given state according to: https://github.com/WICG/web-lifecycle/ setWebLifecycleState
Fields
method: SetWebLifecycleStateMethodparams: SetWebLifecycleStateParamsImplementations
Sourceimpl SetWebLifecycleState
impl SetWebLifecycleState
pub fn builder() -> SetWebLifecycleStateBuilder
Sourceimpl SetWebLifecycleState
impl SetWebLifecycleState
pub const IDENTIFIER: &'static str = "Page.setWebLifecycleState"
pub fn identifier(&self) -> &'static str