pub struct SetWebLifecycleStateParams {
pub state: SetWebLifecycleStateState,
}Expand description
Tries to update the web lifecycle state of the page. It will transition the page to the given state according to: https://github.com/WICG/web-lifecycle/ setWebLifecycleState
Fields
state: SetWebLifecycleStateStateTarget lifecycle state
Implementations
Sourceimpl SetWebLifecycleStateParams
impl SetWebLifecycleStateParams
pub fn new(state: impl Into<SetWebLifecycleStateState>) -> Self