Module events

Module events 

Structs

BackForwardCacheNotUsed
Fired for failed bfcache history navigations if BackForwardCache feature is enabled. Do not assume any ordering with the Page.frameNavigated event. This event is fired only for main-frame history navigation where the document changes (non-same-document navigations), when bfcache navigation fails. backForwardCacheNotUsed
BackForwardCacheNotUsedParams
Fired for failed bfcache history navigations if BackForwardCache feature is enabled. Do not assume any ordering with the Page.frameNavigated event. This event is fired only for main-frame history navigation where the document changes (non-same-document navigations), when bfcache navigation fails. backForwardCacheNotUsed
CompilationCacheProduced
Issued for every compilation cache generated. compilationCacheProduced
CompilationCacheProducedParams
Issued for every compilation cache generated. compilationCacheProduced
DocumentOpened
Fired when opening document to write to. documentOpened
DocumentOpenedParams
Fired when opening document to write to. documentOpened
DomContentEventFired
DomContentEventFiredParams
FileChooserOpened
Emitted only when page.interceptFileChooser is enabled. fileChooserOpened
FileChooserOpenedParams
Emitted only when page.interceptFileChooser is enabled. fileChooserOpened
FrameAttached
Fired when frame has been attached to its parent. frameAttached
FrameAttachedParams
Fired when frame has been attached to its parent. frameAttached
FrameDetached
Fired when frame has been detached from its parent. frameDetached
FrameDetachedParams
Fired when frame has been detached from its parent. frameDetached
FrameNavigated
Fired once navigation of the frame has completed. Frame is now associated with the new loader. frameNavigated
FrameNavigatedParams
Fired once navigation of the frame has completed. Frame is now associated with the new loader. frameNavigated
FrameRequestedNavigation
Fired when a renderer-initiated navigation is requested. Navigation may still be cancelled after the event is issued. frameRequestedNavigation
FrameRequestedNavigationParams
Fired when a renderer-initiated navigation is requested. Navigation may still be cancelled after the event is issued. frameRequestedNavigation
FrameResized
FrameResizedParams
FrameStartedLoading
Fired when frame has started loading. frameStartedLoading
FrameStartedLoadingParams
Fired when frame has started loading. frameStartedLoading
FrameStartedNavigating
Fired when a navigation starts. This event is fired for both renderer-initiated and browser-initiated navigations. For renderer-initiated navigations, the event is fired after frameRequestedNavigation. Navigation may still be cancelled after the event is issued. Multiple events can be fired for a single navigation, for example, when a same-document navigation becomes a cross-document navigation (such as in the case of a frameset). frameStartedNavigating
FrameStartedNavigatingParams
Fired when a navigation starts. This event is fired for both renderer-initiated and browser-initiated navigations. For renderer-initiated navigations, the event is fired after frameRequestedNavigation. Navigation may still be cancelled after the event is issued. Multiple events can be fired for a single navigation, for example, when a same-document navigation becomes a cross-document navigation (such as in the case of a frameset). frameStartedNavigating
FrameStoppedLoading
Fired when frame has stopped loading. frameStoppedLoading
FrameStoppedLoadingParams
Fired when frame has stopped loading. frameStoppedLoading
FrameSubtreeWillBeDetached
Fired before frame subtree is detached. Emitted before any frame of the subtree is actually detached. frameSubtreeWillBeDetached
FrameSubtreeWillBeDetachedParams
Fired before frame subtree is detached. Emitted before any frame of the subtree is actually detached. frameSubtreeWillBeDetached
InterstitialHidden
Fired when interstitial page was hidden interstitialHidden
InterstitialHiddenParams
Fired when interstitial page was hidden interstitialHidden
InterstitialShown
Fired when interstitial page was shown interstitialShown
InterstitialShownParams
Fired when interstitial page was shown interstitialShown
JavascriptDialogClosed
Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) has been closed. javascriptDialogClosed
JavascriptDialogClosedParams
Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) has been closed. javascriptDialogClosed
JavascriptDialogOpening
Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) is about to open. javascriptDialogOpening
JavascriptDialogOpeningParams
Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) is about to open. javascriptDialogOpening
LifecycleEvent
Fired for lifecycle events (navigation, load, paint, etc) in the current target (including local frames). lifecycleEvent
LifecycleEventParams
Fired for lifecycle events (navigation, load, paint, etc) in the current target (including local frames). lifecycleEvent
LoadEventFired
LoadEventFiredParams
NavigatedWithinDocument
Fired when same-document navigation happens, e.g. due to history API usage or anchor navigation. navigatedWithinDocument
NavigatedWithinDocumentParams
Fired when same-document navigation happens, e.g. due to history API usage or anchor navigation. navigatedWithinDocument
ScreencastFrame
Compressed image data requested by the startScreencast. screencastFrame
ScreencastFrameParams
Compressed image data requested by the startScreencast. screencastFrame
ScreencastVisibilityChanged
Fired when the page with currently enabled screencast was shown or hidden `. screencastVisibilityChanged
ScreencastVisibilityChangedParams
Fired when the page with currently enabled screencast was shown or hidden `. screencastVisibilityChanged
WindowOpen
Fired when a new window is going to be opened, via window.open(), link click, form submission, etc. windowOpen
WindowOpenParams
Fired when a new window is going to be opened, via window.open(), link click, form submission, etc. windowOpen

Enums

BackForwardCacheNotUsedMethod
CompilationCacheProducedMethod
DocumentOpenedMethod
DomContentEventFiredMethod
FileChooserOpenedMethod
FileChooserOpenedMode
Input mode.
FrameAttachedMethod
FrameDetachedMethod
FrameDetachedReason
FrameNavigatedMethod
FrameRequestedNavigationMethod
FrameResizedMethod
FrameStartedLoadingMethod
FrameStartedNavigatingMethod
FrameStartedNavigatingNavigationType
FrameStoppedLoadingMethod
FrameSubtreeWillBeDetachedMethod
InterstitialHiddenMethod
InterstitialShownMethod
JavascriptDialogClosedMethod
JavascriptDialogOpeningMethod
LifecycleEventMethod
LoadEventFiredMethod
NavigatedWithinDocumentMethod
NavigatedWithinDocumentNavigationType
Navigation type
PageEvents
ScreencastFrameMethod
ScreencastVisibilityChangedMethod
WindowOpenMethod