pub struct BackForwardCacheNotUsedParams {
pub loader_id: LoaderId,
pub frame_id: Box<FrameId>,
pub not_restored_explanations: Vec<BackForwardCacheNotRestoredExplanation>,
pub not_restored_explanations_tree: Option<BackForwardCacheNotRestoredExplanationTree>,
}Expand description
Fired for failed bfcache history navigations if BackForwardCache feature is enabled. Do not assume any ordering with the Page.frameNavigated event. This event is fired only for main-frame history navigation where the document changes (non-same-document navigations), when bfcache navigation fails. backForwardCacheNotUsed
Fields
loader_id: LoaderIdThe loader id for the associated navigation.
frame_id: Box<FrameId>The frame id of the associated frame.
not_restored_explanations: Vec<BackForwardCacheNotRestoredExplanation>Array of reasons why the page could not be cached. This must not be empty.
not_restored_explanations_tree: Option<BackForwardCacheNotRestoredExplanationTree>Tree structure of reasons why the page could not be cached for each frame.