pub struct FrameAttachedParams {
pub frame_id: Box<FrameId>,
pub parent_frame_id: FrameId,
pub stack: Option<StackTrace>,
}Expand description
Fired when frame has been attached to its parent. frameAttached
Fields
frame_id: Box<FrameId>Id of the frame that has been attached.
parent_frame_id: FrameIdParent frame identifier.
stack: Option<StackTrace>JavaScript stack trace of when frame was attached, only set if frame initiated from script.