pub struct FrameStartedNavigating {
pub method: FrameStartedNavigatingMethod,
pub params: FrameStartedNavigatingParams,
}Expand description
Fired when a navigation starts. This event is fired for both
renderer-initiated and browser-initiated navigations. For renderer-initiated
navigations, the event is fired after frameRequestedNavigation.
Navigation may still be cancelled after the event is issued. Multiple events
can be fired for a single navigation, for example, when a same-document
navigation becomes a cross-document navigation (such as in the case of a
frameset).
frameStartedNavigating
Fields
method: FrameStartedNavigatingMethodparams: FrameStartedNavigatingParamsImplementations
pub const IDENTIFIER: &'static str = "Page.frameStartedNavigating"
pub fn identifier(&self) -> &'static str