pub struct FrameStartedNavigatingParams {
pub frame_id: Box<FrameId>,
pub url: String,
pub loader_id: LoaderId,
pub navigation_type: FrameStartedNavigatingNavigationType,
}Expand description
Fired when a navigation starts. This event is fired for both
renderer-initiated and browser-initiated navigations. For renderer-initiated
navigations, the event is fired after frameRequestedNavigation.
Navigation may still be cancelled after the event is issued. Multiple events
can be fired for a single navigation, for example, when a same-document
navigation becomes a cross-document navigation (such as in the case of a
frameset).
frameStartedNavigating
Fields
frame_id: Box<FrameId>ID of the frame that is being navigated.
url: StringThe URL the navigation started with. The final URL can be different.
loader_id: LoaderIdLoader identifier. Even though it is present in case of same-document navigation, the previously committed loaderId would not change unless the navigation changes from a same-document to a cross-document navigation.