pub struct WindowOpenParams {
pub url: String,
pub window_name: String,
pub window_features: Vec<String>,
pub user_gesture: bool,
}Expand description
Fired when a new window is going to be opened, via window.open(), link click, form submission, etc. windowOpen
Fields
url: StringThe URL for the new window.
window_name: StringWindow name.
window_features: Vec<String>An array of enabled window features.
user_gesture: boolWhether or not it was triggered by user gesture.