pub struct EnableParams {
pub event_types: Vec<String>,
}Expand description
Previously buffered events would be reported before method returns. See also: timelineEventAdded enable
Fields
event_types: Vec<String>The types of event to report, as specified in https://w3c.github.io/performance-timeline/#dom-performanceentry-entrytype The specified filter overrides any previous filters, passing empty filter disables recording. Note that not all types exposed to the web platform are currently supported.
Implementations