pub struct PreloadingAttemptSourcesUpdatedParams {
pub loader_id: LoaderId,
pub preloading_attempt_sources: Vec<PreloadingAttemptSource>,
}Expand description
Send a list of sources for all preloading attempts in a document. preloadingAttemptSourcesUpdated
Fields
loader_id: LoaderIdpreloading_attempt_sources: Vec<PreloadingAttemptSource>Trait Implementations
Sourceimpl Clone for PreloadingAttemptSourcesUpdatedParams
impl Clone for PreloadingAttemptSourcesUpdatedParams
Sourcefn clone(&self) -> PreloadingAttemptSourcesUpdatedParams
fn clone(&self) -> PreloadingAttemptSourcesUpdatedParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PreloadingAttemptSourcesUpdatedParams
impl<'de> Deserialize<'de> for PreloadingAttemptSourcesUpdatedParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PreloadingAttemptSourcesUpdatedParams
impl PartialEq for PreloadingAttemptSourcesUpdatedParams
Sourcefn eq(&self, other: &PreloadingAttemptSourcesUpdatedParams) -> bool
fn eq(&self, other: &PreloadingAttemptSourcesUpdatedParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PreloadingAttemptSourcesUpdatedParams