pub struct Launch {
pub method: LaunchMethod,
pub params: LaunchParams,
}Expand description
Launches the installed web app, or an url in the same web app instead of the default start url if it is provided. Returns a page Target.TargetID which can be used to attach to via Target.attachToTarget or similar APIs. launch
Fields
method: LaunchMethodparams: LaunchParamsImplementations
Sourceimpl Launch
impl Launch
pub const IDENTIFIER: &'static str = "PWA.launch"
pub fn identifier(&self) -> &'static str