pub struct LaunchParams {
pub manifest_id: String,
pub url: Option<String>,
}Expand description
Launches the installed web app, or an url in the same web app instead of the default start url if it is provided. Returns a page Target.TargetID which can be used to attach to via Target.attachToTarget or similar APIs. launch
Fields
manifest_id: Stringurl: Option<String>Implementations