pub struct OpenCurrentPageInApp {
pub method: OpenCurrentPageInAppMethod,
pub params: OpenCurrentPageInAppParams,
}Expand description
Opens the current page in its web app identified by the manifest id, needs to be called on a page target. This function returns immediately without waiting for the app to finish loading. openCurrentPageInApp
Fields
method: OpenCurrentPageInAppMethodparams: OpenCurrentPageInAppParamsImplementations
Sourceimpl OpenCurrentPageInApp
impl OpenCurrentPageInApp
pub fn builder() -> OpenCurrentPageInAppBuilder
Sourceimpl OpenCurrentPageInApp
impl OpenCurrentPageInApp
pub const IDENTIFIER: &'static str = "PWA.openCurrentPageInApp"
pub fn identifier(&self) -> &'static str