pub struct OpenCurrentPageInAppParams {
pub manifest_id: String,
}Expand description
Opens the current page in its web app identified by the manifest id, needs to be called on a page target. This function returns immediately without waiting for the app to finish loading. openCurrentPageInApp
Fields
manifest_id: StringImplementations