pub struct GetRelatedWebsiteSets {
pub method: GetRelatedWebsiteSetsMethod,
pub params: GetRelatedWebsiteSetsParams,
}Expand description
Returns the effective Related Website Sets in use by this profile for the browser session. The effective Related Website Sets will not change during a browser session. getRelatedWebsiteSets
Fields
method: GetRelatedWebsiteSetsMethodparams: GetRelatedWebsiteSetsParamsImplementations
Sourceimpl GetRelatedWebsiteSets
impl GetRelatedWebsiteSets
pub fn builder() -> GetRelatedWebsiteSetsBuilder
Sourceimpl GetRelatedWebsiteSets
impl GetRelatedWebsiteSets
pub const IDENTIFIER: &'static str = "Storage.getRelatedWebsiteSets"
pub fn identifier(&self) -> &'static str