pub struct GetRelatedWebsiteSetsParams {}Expand description
Returns the effective Related Website Sets in use by this profile for the browser session. The effective Related Website Sets will not change during a browser session. getRelatedWebsiteSets