Module events

Structs

AttributionReportingReportSent
AttributionReportingReportSentParams
AttributionReportingSourceRegistered
AttributionReportingSourceRegisteredParams
AttributionReportingTriggerRegistered
AttributionReportingTriggerRegisteredParams
AttributionReportingVerboseDebugReportSent
AttributionReportingVerboseDebugReportSentParams
CacheStorageContentUpdated
A cache’s contents have been modified. cacheStorageContentUpdated
CacheStorageContentUpdatedParams
A cache’s contents have been modified. cacheStorageContentUpdated
CacheStorageListUpdated
A cache has been added/deleted. cacheStorageListUpdated
CacheStorageListUpdatedParams
A cache has been added/deleted. cacheStorageListUpdated
IndexedDbContentUpdated
The origin’s IndexedDB object store has been modified. indexedDBContentUpdated
IndexedDbContentUpdatedParams
The origin’s IndexedDB object store has been modified. indexedDBContentUpdated
IndexedDbListUpdated
The origin’s IndexedDB database list has been modified. indexedDBListUpdated
IndexedDbListUpdatedParams
The origin’s IndexedDB database list has been modified. indexedDBListUpdated
InterestGroupAccessed
One of the interest groups was accessed. Note that these events are global to all targets sharing an interest group store. interestGroupAccessed
InterestGroupAccessedParams
One of the interest groups was accessed. Note that these events are global to all targets sharing an interest group store. interestGroupAccessed
InterestGroupAuctionEventOccurred
An auction involving interest groups is taking place. These events are target-specific. interestGroupAuctionEventOccurred
InterestGroupAuctionEventOccurredParams
An auction involving interest groups is taking place. These events are target-specific. interestGroupAuctionEventOccurred
InterestGroupAuctionNetworkRequestCreated
Specifies which auctions a particular network fetch may be related to, and in what role. Note that it is not ordered with respect to Network.requestWillBeSent (but will happen before loadingFinished loadingFailed). interestGroupAuctionNetworkRequestCreated
InterestGroupAuctionNetworkRequestCreatedParams
Specifies which auctions a particular network fetch may be related to, and in what role. Note that it is not ordered with respect to Network.requestWillBeSent (but will happen before loadingFinished loadingFailed). interestGroupAuctionNetworkRequestCreated
SharedStorageAccessed
Shared storage was accessed by the associated page. The following parameters are included in all events. sharedStorageAccessed
SharedStorageAccessedParams
Shared storage was accessed by the associated page. The following parameters are included in all events. sharedStorageAccessed
SharedStorageWorkletOperationExecutionFinished
A shared storage run or selectURL operation finished its execution. The following parameters are included in all events. sharedStorageWorkletOperationExecutionFinished
SharedStorageWorkletOperationExecutionFinishedParams
A shared storage run or selectURL operation finished its execution. The following parameters are included in all events. sharedStorageWorkletOperationExecutionFinished
StorageBucketCreatedOrUpdated
StorageBucketCreatedOrUpdatedParams
StorageBucketDeleted
StorageBucketDeletedParams

Enums

AttributionReportingReportSentMethod
AttributionReportingSourceRegisteredMethod
AttributionReportingTriggerRegisteredMethod
AttributionReportingVerboseDebugReportSentMethod
CacheStorageContentUpdatedMethod
CacheStorageListUpdatedMethod
IndexedDbContentUpdatedMethod
IndexedDbListUpdatedMethod
InterestGroupAccessedMethod
InterestGroupAuctionEventOccurredMethod
InterestGroupAuctionNetworkRequestCreatedMethod
SharedStorageAccessedMethod
SharedStorageWorkletOperationExecutionFinishedMethod
StorageBucketCreatedOrUpdatedMethod
StorageBucketDeletedMethod
StorageEvents