pub struct InterestGroupAccessedParams {
pub access_time: TimeSinceEpoch,
pub type: InterestGroupAccessType,
pub owner_origin: String,
pub name: String,
pub component_seller_origin: Option<String>,
pub bid: Option<f64>,
pub bid_currency: Option<String>,
pub unique_auction_id: Option<InterestGroupAuctionId>,
}Expand description
One of the interest groups was accessed. Note that these events are global to all targets sharing an interest group store. interestGroupAccessed
Fields
access_time: TimeSinceEpochtype: InterestGroupAccessTypeowner_origin: Stringname: Stringcomponent_seller_origin: Option<String>For topLevelBid/topLevelAdditionalBid, and when appropriate, win and additionalBidWin
bid: Option<f64>For bid or somethingBid event, if done locally and not on a server.
bid_currency: Option<String>unique_auction_id: Option<InterestGroupAuctionId>For non-global events — links to interestGroupAuctionEvent