pub struct InterestGroupAuctionNetworkRequestCreated {
pub method: InterestGroupAuctionNetworkRequestCreatedMethod,
pub params: InterestGroupAuctionNetworkRequestCreatedParams,
}Expand description
Specifies which auctions a particular network fetch may be related to, and in what role. Note that it is not ordered with respect to Network.requestWillBeSent (but will happen before loadingFinished loadingFailed). interestGroupAuctionNetworkRequestCreated
Fields
method: InterestGroupAuctionNetworkRequestCreatedMethodparams: InterestGroupAuctionNetworkRequestCreatedParamsImplementations
Sourceimpl InterestGroupAuctionNetworkRequestCreated
impl InterestGroupAuctionNetworkRequestCreated
pub const IDENTIFIER: &'static str = "Storage.interestGroupAuctionNetworkRequestCreated"
pub fn identifier(&self) -> &'static str