InterestGroupAuctionNetworkRequestCreatedParams

Struct InterestGroupAuctionNetworkRequestCreatedParams 

pub struct InterestGroupAuctionNetworkRequestCreatedParams {
    pub type: InterestGroupAuctionFetchType,
    pub request_id: RequestId,
    pub auctions: Vec<InterestGroupAuctionId>,
}
Specifies which auctions a particular network fetch may be related to, and in what role. Note that it is not ordered with respect to Network.requestWillBeSent (but will happen before loadingFinished loadingFailed). interestGroupAuctionNetworkRequestCreated

Fields

type: InterestGroupAuctionFetchTyperequest_id: RequestIdauctions: Vec<InterestGroupAuctionId>

This is the set of the auctions using the worklet that issued this request. In the case of trusted signals, it’s possible that only some of them actually care about the keys being queried.