pub struct SharedStorageWorkletOperationExecutionFinishedParams {
pub finished_time: TimeSinceEpoch,
pub execution_time: i64,
pub method: SharedStorageAccessMethod,
pub operation_id: String,
pub worklet_target_id: TargetId,
pub main_frame_id: FrameId,
pub owner_origin: String,
}Expand description
A shared storage run or selectURL operation finished its execution. The following parameters are included in all events. sharedStorageWorkletOperationExecutionFinished
Fields
finished_time: TimeSinceEpochTime that the operation finished.
execution_time: i64Time, in microseconds, from start of shared storage JS API call until end of operation execution in the worklet.
method: SharedStorageAccessMethodEnum value indicating the Shared Storage API method invoked.
operation_id: StringID of the operation call.
worklet_target_id: TargetIdHex representation of the DevTools token used as the TargetID for the associated shared storage worklet.
main_frame_id: FrameIdDevTools Frame Token for the primary frame tree’s root.
owner_origin: StringSerialization of the origin owning the Shared Storage data.