Module commands

Module commands 

Structs

ActivateTarget
Activates (focuses) the target. activateTarget
ActivateTargetParams
Activates (focuses) the target. activateTarget
AttachToBrowserTarget
Attaches to the browser target, only uses flat sessionId mode. attachToBrowserTarget
AttachToBrowserTargetParams
Attaches to the browser target, only uses flat sessionId mode. attachToBrowserTarget
AttachToTarget
Attaches to the target with given id. attachToTarget
AttachToTargetParams
Attaches to the target with given id. attachToTarget
AutoAttachRelated
Adds the specified target to the list of targets that will be monitored for any related target creation (such as child frames, child workers and new versions of service worker) and reported through attachedToTarget. The specified target is also auto-attached. This cancels the effect of any previous setAutoAttach and is also cancelled by subsequent setAutoAttach. Only available at the Browser target. autoAttachRelated
AutoAttachRelatedParams
Adds the specified target to the list of targets that will be monitored for any related target creation (such as child frames, child workers and new versions of service worker) and reported through attachedToTarget. The specified target is also auto-attached. This cancels the effect of any previous setAutoAttach and is also cancelled by subsequent setAutoAttach. Only available at the Browser target. autoAttachRelated
CloseTarget
Closes the target. If the target is a page that gets closed too. closeTarget
CloseTargetParams
Closes the target. If the target is a page that gets closed too. closeTarget
CreateBrowserContext
Creates a new empty BrowserContext. Similar to an incognito profile but you can have more than one. createBrowserContext
CreateBrowserContextParams
Creates a new empty BrowserContext. Similar to an incognito profile but you can have more than one. createBrowserContext
CreateTarget
Creates a new page. createTarget
CreateTargetParams
Creates a new page. createTarget
DetachFromTarget
Detaches session with given id. detachFromTarget
DetachFromTargetParams
Detaches session with given id. detachFromTarget
DisposeBrowserContext
Deletes a BrowserContext. All the belonging pages will be closed without calling their beforeunload hooks. disposeBrowserContext
DisposeBrowserContextParams
Deletes a BrowserContext. All the belonging pages will be closed without calling their beforeunload hooks. disposeBrowserContext
ExposeDevToolsProtocol
Inject object to the target’s main frame that provides a communication channel with browser target.
ExposeDevToolsProtocolParams
Inject object to the target’s main frame that provides a communication channel with browser target.
GetBrowserContexts
Returns all browser contexts created with Target.createBrowserContext method. getBrowserContexts
GetBrowserContextsParams
Returns all browser contexts created with Target.createBrowserContext method. getBrowserContexts
GetDevToolsTarget
Gets the targetId of the DevTools page target opened for the given target (if any). getDevToolsTarget
GetDevToolsTargetParams
Gets the targetId of the DevTools page target opened for the given target (if any). getDevToolsTarget
GetTargetInfo
Returns information about a target. getTargetInfo
GetTargetInfoParams
Returns information about a target. getTargetInfo
GetTargets
Retrieves a list of available targets. getTargets
GetTargetsParams
Retrieves a list of available targets. getTargets
OpenDevTools
Opens a DevTools window for the target. openDevTools
OpenDevToolsParams
Opens a DevTools window for the target. openDevTools
SetAutoAttach
Controls whether to automatically attach to new targets which are considered to be directly related to this one (for example, iframes or workers). When turned on, attaches to all existing related targets as well. When turned off, automatically detaches from all currently attached targets. This also clears all targets added by autoAttachRelated from the list of targets to watch for creation of related targets. You might want to call this recursively for auto-attached targets to attach to all available targets. setAutoAttach
SetAutoAttachParams
Controls whether to automatically attach to new targets which are considered to be directly related to this one (for example, iframes or workers). When turned on, attaches to all existing related targets as well. When turned off, automatically detaches from all currently attached targets. This also clears all targets added by autoAttachRelated from the list of targets to watch for creation of related targets. You might want to call this recursively for auto-attached targets to attach to all available targets. setAutoAttach
SetDiscoverTargets
Controls whether to discover available targets and notify via targetCreated/targetInfoChanged/targetDestroyed events. setDiscoverTargets
SetDiscoverTargetsParams
Controls whether to discover available targets and notify via targetCreated/targetInfoChanged/targetDestroyed events. setDiscoverTargets
SetRemoteLocations
Enables target discovery for the specified locations, when setDiscoverTargets was set to true. setRemoteLocations
SetRemoteLocationsParams
Enables target discovery for the specified locations, when setDiscoverTargets was set to true. setRemoteLocations

Enums

ActivateTargetMethod
AttachToBrowserTargetMethod
AttachToTargetMethod
AutoAttachRelatedMethod
CloseTargetMethod
CreateBrowserContextMethod
CreateTargetMethod
DetachFromTargetMethod
DisposeBrowserContextMethod
ExposeDevToolsProtocolMethod
GetBrowserContextsMethod
GetDevToolsTargetMethod
GetTargetInfoMethod
GetTargetsMethod
OpenDevToolsMethod
SetAutoAttachMethod
SetDiscoverTargetsMethod
SetRemoteLocationsMethod
TargetCommands