pub struct AutoAttachRelated {
pub method: AutoAttachRelatedMethod,
pub params: AutoAttachRelatedParams,
}Expand description
Adds the specified target to the list of targets that will be monitored for any related target
creation (such as child frames, child workers and new versions of service worker) and reported
through attachedToTarget. The specified target is also auto-attached.
This cancels the effect of any previous setAutoAttach and is also cancelled by subsequent
setAutoAttach. Only available at the Browser target.
autoAttachRelated
Fields
method: AutoAttachRelatedMethodparams: AutoAttachRelatedParamsImplementations
Sourceimpl AutoAttachRelated
impl AutoAttachRelated
pub fn builder() -> AutoAttachRelatedBuilder
Sourceimpl AutoAttachRelated
impl AutoAttachRelated
pub const IDENTIFIER: &'static str = "Target.autoAttachRelated"
pub fn identifier(&self) -> &'static str