pub struct AutoAttachRelatedParams {
pub target_id: TargetId,
pub wait_for_debugger_on_start: bool,
pub filter: Option<TargetFilter>,
}Expand description
Adds the specified target to the list of targets that will be monitored for any related target
creation (such as child frames, child workers and new versions of service worker) and reported
through attachedToTarget. The specified target is also auto-attached.
This cancels the effect of any previous setAutoAttach and is also cancelled by subsequent
setAutoAttach. Only available at the Browser target.
autoAttachRelated
Fields
target_id: TargetIdwait_for_debugger_on_start: boolWhether to pause new targets when attaching to them. Use Runtime.runIfWaitingForDebugger
to run paused targets.
filter: Option<TargetFilter>Only targets matching filter will be attached.
Implementations