pub struct ExposeDevToolsProtocol {
pub method: ExposeDevToolsProtocolMethod,
pub params: ExposeDevToolsProtocolParams,
}Expand description
Inject object to the target’s main frame that provides a communication channel with browser target.
Injected object will be available as window[bindingName].
The object has the following API:
binding.send(json)- a method to send messages over the remote debugging protocolbinding.onmessage = json => handleMessage(json)- a callback that will be called for the protocol notifications and command responses. exposeDevToolsProtocol
Fields
method: ExposeDevToolsProtocolMethodparams: ExposeDevToolsProtocolParamsImplementations
Sourceimpl ExposeDevToolsProtocol
impl ExposeDevToolsProtocol
pub fn builder() -> ExposeDevToolsProtocolBuilder
Sourceimpl ExposeDevToolsProtocol
impl ExposeDevToolsProtocol
pub const IDENTIFIER: &'static str = "Target.exposeDevToolsProtocol"
pub fn identifier(&self) -> &'static str