pub struct ExposeDevToolsProtocolParams {
pub target_id: TargetId,
pub binding_name: Option<String>,
pub inherit_permissions: Option<bool>,
}Expand description
Inject object to the target’s main frame that provides a communication channel with browser target.
Injected object will be available as window[bindingName].
The object has the following API:
binding.send(json)- a method to send messages over the remote debugging protocolbinding.onmessage = json => handleMessage(json)- a callback that will be called for the protocol notifications and command responses. exposeDevToolsProtocol
Fields
target_id: TargetIdbinding_name: Option<String>Binding name, ‘cdp’ if not specified.
inherit_permissions: Option<bool>If true, inherits the current root session’s permissions (default: false).
Implementations