pub struct GetTargetsParams {
pub filter: Option<TargetFilter>,
}Expand description
Retrieves a list of available targets. getTargets
Fields
filter: Option<TargetFilter>Only targets matching filter will be reported. If filter is not specified and target discovery is currently enabled, a filter used for target discovery is used for consistency.