pub struct SetAutoAttach {
pub method: SetAutoAttachMethod,
pub params: SetAutoAttachParams,
}Expand description
Controls whether to automatically attach to new targets which are considered
to be directly related to this one (for example, iframes or workers).
When turned on, attaches to all existing related targets as well. When turned off,
automatically detaches from all currently attached targets.
This also clears all targets added by autoAttachRelated from the list of targets to watch
for creation of related targets.
You might want to call this recursively for auto-attached targets to attach
to all available targets.
setAutoAttach
Fields
method: SetAutoAttachMethodparams: SetAutoAttachParamsImplementations
Sourceimpl SetAutoAttach
impl SetAutoAttach
pub fn builder() -> SetAutoAttachBuilder
Sourceimpl SetAutoAttach
impl SetAutoAttach
pub const IDENTIFIER: &'static str = "Target.setAutoAttach"
pub fn identifier(&self) -> &'static str