pub struct DetachedFromTarget {
pub method: DetachedFromTargetMethod,
pub params: DetachedFromTargetParams,
}Expand description
Issued when detached from target for any reason (including detachFromTarget command). Can be
issued multiple times per target if multiple sessions have been attached to it.
detachedFromTarget
Fields
method: DetachedFromTargetMethodparams: DetachedFromTargetParamsImplementations
Sourceimpl DetachedFromTarget
impl DetachedFromTarget
pub const IDENTIFIER: &'static str = "Target.detachedFromTarget"
pub fn identifier(&self) -> &'static str