Module commands

Module commands 

Structs

End
Stop trace events collection. end
EndParams
Stop trace events collection. end
GetCategories
Gets supported tracing categories. getCategories
GetCategoriesParams
Gets supported tracing categories. getCategories
GetTrackEventDescriptor
Return a descriptor for all available tracing categories. getTrackEventDescriptor
GetTrackEventDescriptorParams
Return a descriptor for all available tracing categories. getTrackEventDescriptor
RecordClockSyncMarker
Record a clock sync marker in the trace. recordClockSyncMarker
RecordClockSyncMarkerParams
Record a clock sync marker in the trace. recordClockSyncMarker
RequestMemoryDump
Request a global memory dump. requestMemoryDump
RequestMemoryDumpParams
Request a global memory dump. requestMemoryDump
Start
Start trace events collection. start
StartParams
Start trace events collection. start

Enums

EndMethod
GetCategoriesMethod
GetTrackEventDescriptorMethod
RecordClockSyncMarkerMethod
RequestMemoryDumpMethod
StartMethod
StartTransferMode
Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to ReportEvents).
TracingCommands