pub struct TracingComplete {
pub method: TracingCompleteMethod,
pub params: TracingCompleteParams,
}Expand description
Signals that tracing is stopped and there is no trace buffers pending flush, all data were delivered via dataCollected events. tracingComplete
Fields
method: TracingCompleteMethodparams: TracingCompleteParamsImplementations
Sourceimpl TracingComplete
impl TracingComplete
pub const IDENTIFIER: &'static str = "Tracing.tracingComplete"
pub fn identifier(&self) -> &'static str