pub struct TracingCompleteParams {
pub data_loss_occurred: bool,
pub stream: Option<StreamHandle>,
pub trace_format: Option<StreamFormat>,
pub stream_compression: Option<StreamCompression>,
}Expand description
Signals that tracing is stopped and there is no trace buffers pending flush, all data were delivered via dataCollected events. tracingComplete
Fields
data_loss_occurred: boolIndicates whether some trace data is known to have been lost, e.g. because the trace ring buffer wrapped around.
stream: Option<StreamHandle>A handle of the stream that holds resulting trace data.
trace_format: Option<StreamFormat>Trace data format of returned stream.
stream_compression: Option<StreamCompression>Compression format of returned stream.