pub struct NodesDisconnected {
pub method: NodesDisconnectedMethod,
pub params: NodesDisconnectedParams,
}Expand description
Notifies that AudioNodes are disconnected. The destination can be null, and it means all the outgoing connections from the source are disconnected. nodesDisconnected
Fields
method: NodesDisconnectedMethodparams: NodesDisconnectedParamsImplementations
Sourceimpl NodesDisconnected
impl NodesDisconnected
pub const IDENTIFIER: &'static str = "WebAudio.nodesDisconnected"
pub fn identifier(&self) -> &'static str