pub struct NodesDisconnectedParams {
pub context_id: GraphObjectId,
pub source_id: GraphObjectId,
pub destination_id: GraphObjectId,
pub source_output_index: Option<f64>,
pub destination_input_index: Option<f64>,
}Expand description
Notifies that AudioNodes are disconnected. The destination can be null, and it means all the outgoing connections from the source are disconnected. nodesDisconnected
Fields
context_id: GraphObjectIdsource_id: GraphObjectIddestination_id: GraphObjectIdsource_output_index: Option<f64>destination_input_index: Option<f64>Trait Implementations
Sourceimpl Clone for NodesDisconnectedParams
impl Clone for NodesDisconnectedParams
Sourcefn clone(&self) -> NodesDisconnectedParams
fn clone(&self) -> NodesDisconnectedParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodesDisconnectedParams
impl Debug for NodesDisconnectedParams
Sourceimpl<'de> Deserialize<'de> for NodesDisconnectedParams
impl<'de> Deserialize<'de> for NodesDisconnectedParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for NodesDisconnectedParams
impl PartialEq for NodesDisconnectedParams
Sourceimpl Serialize for NodesDisconnectedParams
impl Serialize for NodesDisconnectedParams
impl StructuralPartialEq for NodesDisconnectedParams