Module commands

Structs

AddCredential
Adds the credential to the specified authenticator. addCredential
AddCredentialParams
Adds the credential to the specified authenticator. addCredential
AddVirtualAuthenticator
Creates and adds a virtual authenticator. addVirtualAuthenticator
AddVirtualAuthenticatorParams
Creates and adds a virtual authenticator. addVirtualAuthenticator
ClearCredentials
Clears all the credentials from the specified device. clearCredentials
ClearCredentialsParams
Clears all the credentials from the specified device. clearCredentials
Disable
Disable the WebAuthn domain. disable
DisableParams
Disable the WebAuthn domain. disable
Enable
Enable the WebAuthn domain and start intercepting credential storage and retrieval with a virtual authenticator. enable
EnableParams
Enable the WebAuthn domain and start intercepting credential storage and retrieval with a virtual authenticator. enable
GetCredential
Returns a single credential stored in the given virtual authenticator that matches the credential ID. getCredential
GetCredentialParams
Returns a single credential stored in the given virtual authenticator that matches the credential ID. getCredential
GetCredentials
Returns all the credentials stored in the given virtual authenticator. getCredentials
GetCredentialsParams
Returns all the credentials stored in the given virtual authenticator. getCredentials
RemoveCredential
Removes a credential from the authenticator. removeCredential
RemoveCredentialParams
Removes a credential from the authenticator. removeCredential
RemoveVirtualAuthenticator
Removes the given authenticator. removeVirtualAuthenticator
RemoveVirtualAuthenticatorParams
Removes the given authenticator. removeVirtualAuthenticator
SetAutomaticPresenceSimulation
Sets whether tests of user presence will succeed immediately (if true) or fail to resolve (if false) for an authenticator. The default is true. setAutomaticPresenceSimulation
SetAutomaticPresenceSimulationParams
Sets whether tests of user presence will succeed immediately (if true) or fail to resolve (if false) for an authenticator. The default is true. setAutomaticPresenceSimulation
SetCredentialProperties
Allows setting credential properties. https://w3c.github.io/webauthn/#sctn-automation-set-credential-properties setCredentialProperties
SetCredentialPropertiesParams
Allows setting credential properties. https://w3c.github.io/webauthn/#sctn-automation-set-credential-properties setCredentialProperties
SetResponseOverrideBits
Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present. setResponseOverrideBits
SetResponseOverrideBitsParams
Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present. setResponseOverrideBits
SetUserVerified
Sets whether User Verification succeeds or fails for an authenticator. The default is true. setUserVerified
SetUserVerifiedParams
Sets whether User Verification succeeds or fails for an authenticator. The default is true. setUserVerified

Enums

AddCredentialMethod
AddVirtualAuthenticatorMethod
ClearCredentialsMethod
DisableMethod
EnableMethod
GetCredentialMethod
GetCredentialsMethod
RemoveCredentialMethod
RemoveVirtualAuthenticatorMethod
SetAutomaticPresenceSimulationMethod
SetCredentialPropertiesMethod
SetResponseOverrideBitsMethod
SetUserVerifiedMethod
WebAuthnCommands