Enables debugger for the given page. Clients should not assume that the debugging has been
enabled until the result for this command is received.
enable
Enables debugger for the given page. Clients should not assume that the debugging has been
enabled until the result for this command is received.
enable
Disassemble the next chunk of lines for the module corresponding to the
stream. If disassembly is complete, this API will invalidate the streamId
and return an empty chunk. Any subsequent calls for the now invalid stream
will return errors.
nextWasmDisassemblyChunk
Disassemble the next chunk of lines for the module corresponding to the
stream. If disassembly is complete, this API will invalidate the streamId
and return an empty chunk. Any subsequent calls for the now invalid stream
will return errors.
nextWasmDisassemblyChunk
Restarts particular call frame from the beginning. The old, deprecated
behavior of restartFrame is to stay paused and allow further CDP commands
after a restart was scheduled. This can cause problems with restarting, so
we now continue execution immediatly after it has been scheduled until we
reach the beginning of the restarted frame.
Restarts particular call frame from the beginning. The old, deprecated
behavior of restartFrame is to stay paused and allow further CDP commands
after a restart was scheduled. This can cause problems with restarting, so
we now continue execution immediatly after it has been scheduled until we
reach the beginning of the restarted frame.
Replace previous blackbox execution contexts with passed ones. Forces backend to skip
stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by
performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
setBlackboxExecutionContexts
Replace previous blackbox execution contexts with passed ones. Forces backend to skip
stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by
performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
setBlackboxExecutionContexts
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in
scripts with url matching one of the patterns. VM will try to leave blackboxed script by
performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
setBlackboxPatterns
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in
scripts with url matching one of the patterns. VM will try to leave blackboxed script by
performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
setBlackboxPatterns
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted
scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
Positions array contains positions where blackbox state is changed. First interval isn’t
blackboxed. Array should be sorted.
setBlackboxedRanges
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted
scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
Positions array contains positions where blackbox state is changed. First interval isn’t
blackboxed. Array should be sorted.
setBlackboxedRanges
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this
command is issued, all existing parsed scripts will have breakpoints resolved and returned in
locations property. Further matching script parsing will result in subsequent
breakpointResolved events issued. This logical breakpoint will survive page reloads.
setBreakpointByUrl
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this
command is issued, all existing parsed scripts will have breakpoints resolved and returned in
locations property. Further matching script parsing will result in subsequent
breakpointResolved events issued. This logical breakpoint will survive page reloads.
setBreakpointByUrl
Sets JavaScript breakpoint before each call to the given function.
If another function was created from the same source as a given one,
calling it will also trigger the breakpoint.
setBreakpointOnFunctionCall
Sets JavaScript breakpoint before each call to the given function.
If another function was created from the same source as a given one,
calling it will also trigger the breakpoint.
setBreakpointOnFunctionCall
Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions,
or caught exceptions, no exceptions. Initial pause on exceptions state is none.
setPauseOnExceptions
Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions,
or caught exceptions, no exceptions. Initial pause on exceptions state is none.
setPauseOnExceptions