pub struct EnableParams {
pub max_scripts_cache_size: Option<f64>,
}Expand description
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received. enable
Fields
max_scripts_cache_size: Option<f64>The maximum size in bytes of collected scripts (not referenced by other heap objects) the debugger can hold. Puts no limit if parameter is omitted.