pub struct NextWasmDisassemblyChunkParams {
pub stream_id: String,
}Expand description
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors. nextWasmDisassemblyChunk
Fields
stream_id: StringImplementations