RestartFrame

Struct RestartFrame 

pub struct RestartFrame {
    pub method: RestartFrameMethod,
    pub params: RestartFrameParams,
}
Restarts particular call frame from the beginning. The old, deprecated behavior of restartFrame is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.

To stay back-wards compatible, restartFrame now expects a mode parameter to be present. If the mode parameter is missing, restartFrame errors out.

The various return values are deprecated and callFrames is always empty. Use the call frames from the Debugger#paused events instead, that fires once V8 pauses at the beginning of the restarted function. restartFrame

Fields

method: RestartFrameMethodparams: RestartFrameParams

Implementations

Source

impl RestartFrame

Source

impl RestartFrame

pub const IDENTIFIER: &'static str = "Debugger.restartFrame"

pub fn identifier(&self) -> &'static str