pub struct SetBlackboxPatterns {
pub method: SetBlackboxPatternsMethod,
pub params: SetBlackboxPatternsParams,
}Expand description
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. setBlackboxPatterns
Fields
method: SetBlackboxPatternsMethodparams: SetBlackboxPatternsParamsImplementations
Sourceimpl SetBlackboxPatterns
impl SetBlackboxPatterns
pub fn builder() -> SetBlackboxPatternsBuilder
Sourceimpl SetBlackboxPatterns
impl SetBlackboxPatterns
pub const IDENTIFIER: &'static str = "Debugger.setBlackboxPatterns"
pub fn identifier(&self) -> &'static str