pub struct SetBlackboxPatternsParams {
pub patterns: Vec<String>,
pub skip_anonymous: Option<bool>,
}Expand description
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. setBlackboxPatterns
Fields
patterns: Vec<String>Array of regexps that will be used to check script url for blackbox state.
skip_anonymous: Option<bool>If true, also ignore scripts with no source url.
Implementations