pub struct SetBreakpointByUrl {
pub method: SetBreakpointByUrlMethod,
pub params: SetBreakpointByUrlParams,
}Expand description
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this
command is issued, all existing parsed scripts will have breakpoints resolved and returned in
locations property. Further matching script parsing will result in subsequent
breakpointResolved events issued. This logical breakpoint will survive page reloads.
setBreakpointByUrl
Fields
method: SetBreakpointByUrlMethodparams: SetBreakpointByUrlParamsImplementations
Sourceimpl SetBreakpointByUrl
impl SetBreakpointByUrl
pub fn builder() -> SetBreakpointByUrlBuilder
Sourceimpl SetBreakpointByUrl
impl SetBreakpointByUrl
pub const IDENTIFIER: &'static str = "Debugger.setBreakpointByUrl"
pub fn identifier(&self) -> &'static str