pub struct SetBreakpointOnFunctionCall {
pub method: SetBreakpointOnFunctionCallMethod,
pub params: SetBreakpointOnFunctionCallParams,
}Expand description
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint. setBreakpointOnFunctionCall
Fields
method: SetBreakpointOnFunctionCallMethodparams: SetBreakpointOnFunctionCallParamsImplementations
Sourceimpl SetBreakpointOnFunctionCall
impl SetBreakpointOnFunctionCall
pub const IDENTIFIER: &'static str = "Debugger.setBreakpointOnFunctionCall"
pub fn identifier(&self) -> &'static str