pub struct SetScriptSource {
pub method: SetScriptSourceMethod,
pub params: SetScriptSourceParams,
}Expand description
Edits JavaScript source live.
In general, functions that are currently on the stack can not be edited with
a single exception: If the edited function is the top-most stack frame and
that is the only activation of that function on the stack. In this case
the live edit will be successful and a Debugger.restartFrame for the
top-most function is automatically triggered.
setScriptSource
Fields
method: SetScriptSourceMethodparams: SetScriptSourceParamsImplementations
Sourceimpl SetScriptSource
impl SetScriptSource
pub fn builder() -> SetScriptSourceBuilder
Sourceimpl SetScriptSource
impl SetScriptSource
pub const IDENTIFIER: &'static str = "Debugger.setScriptSource"
pub fn identifier(&self) -> &'static str