pub struct SetVariableValueParams {
pub scope_number: i64,
pub variable_name: String,
pub new_value: CallArgument,
pub call_frame_id: CallFrameId,
}Expand description
Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually. setVariableValue
Fields
scope_number: i640-based number of scope as was listed in scope chain. Only ‘local’, ‘closure’ and ‘catch’ scope types are allowed. Other scopes could be manipulated manually.
variable_name: StringVariable name.
new_value: CallArgumentNew variable value.
call_frame_id: CallFrameIdId of callframe that holds variable.
Implementations
Sourceimpl SetVariableValueParams
impl SetVariableValueParams
pub fn new( scope_number: impl Into<i64>, variable_name: impl Into<String>, new_value: impl Into<CallArgument>, call_frame_id: impl Into<CallFrameId>, ) -> Self