pub struct StepIntoParams {
pub break_on_async_call: Option<bool>,
pub skip_list: Option<Vec<LocationRange>>,
}Expand description
Steps into the function call. stepInto
Fields
break_on_async_call: Option<bool>Debugger will pause on the execution of the first async task which was scheduled before next pause.
skip_list: Option<Vec<LocationRange>>The skipList specifies location ranges that should be skipped on step into.