pub struct AddInspectedHeapObjectParams {
pub heap_object_id: HeapSnapshotObjectId,
}Expand description
Enables console to refer to the node with given id via $x (see Command Line API for more details $x functions). addInspectedHeapObject
Fields
heap_object_id: HeapSnapshotObjectIdHeap snapshot object id to be accessible by means of $x command line API.
Implementations
Sourceimpl AddInspectedHeapObjectParams
impl AddInspectedHeapObjectParams
pub fn new(heap_object_id: impl Into<HeapSnapshotObjectId>) -> Self