pub struct StopTrackingHeapObjectsParams {
pub report_progress: Option<bool>,
pub capture_numeric_value: Option<bool>,
pub expose_internals: Option<bool>,
}Fields
report_progress: Option<bool>If true ‘reportHeapSnapshotProgress’ events will be generated while snapshot is being taken when the tracking is stopped.
capture_numeric_value: Option<bool>If true, numerical values are included in the snapshot
expose_internals: Option<bool>If true, exposes internals of the snapshot.