pub struct HeapStatsUpdate {
pub method: HeapStatsUpdateMethod,
pub params: HeapStatsUpdateParams,
}Expand description
If heap objects tracking has been started then backend may send update for one or more fragments heapStatsUpdate
Fields
method: HeapStatsUpdateMethodparams: HeapStatsUpdateParamsImplementations
Sourceimpl HeapStatsUpdate
impl HeapStatsUpdate
pub const IDENTIFIER: &'static str = "HeapProfiler.heapStatsUpdate"
pub fn identifier(&self) -> &'static str