pub struct HeapStatsUpdateParams {
pub stats_update: Vec<i64>,
}Expand description
If heap objects tracking has been started then backend may send update for one or more fragments heapStatsUpdate
Fields
stats_update: Vec<i64>An array of triplets. Each triplet describes a fragment. The first integer is the fragment index, the second integer is a total count of objects for the fragment, the third integer is a total size of the objects for the fragment.