pub struct LastSeenObjectId {
pub method: LastSeenObjectIdMethod,
pub params: LastSeenObjectIdParams,
}Expand description
If heap objects tracking has been started then backend regularly sends a current value for last seen object id and corresponding timestamp. If the were changes in the heap since last event then one or more heapStatsUpdate events will be sent before a new lastSeenObjectId event. lastSeenObjectId
Fields
method: LastSeenObjectIdMethodparams: LastSeenObjectIdParamsImplementations
Sourceimpl LastSeenObjectId
impl LastSeenObjectId
pub const IDENTIFIER: &'static str = "HeapProfiler.lastSeenObjectId"
pub fn identifier(&self) -> &'static str