StartPreciseCoverage

Struct StartPreciseCoverage 

pub struct StartPreciseCoverage {
    pub method: StartPreciseCoverageMethod,
    pub params: StartPreciseCoverageParams,
}
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters. startPreciseCoverage

Fields

method: StartPreciseCoverageMethodparams: StartPreciseCoverageParams

Implementations

Source

impl StartPreciseCoverage

Source

impl StartPreciseCoverage

pub const IDENTIFIER: &'static str = "Profiler.startPreciseCoverage"

pub fn identifier(&self) -> &'static str