StartPreciseCoverageParams

Struct StartPreciseCoverageParams 

pub struct StartPreciseCoverageParams {
    pub call_count: Option<bool>,
    pub detailed: Option<bool>,
    pub allow_triggered_updates: Option<bool>,
}
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters. startPreciseCoverage

Fields

call_count: Option<bool>

Collect accurate call counts beyond simple ‘covered’ or ‘not covered’.

detailed: Option<bool>

Collect block-based coverage.

allow_triggered_updates: Option<bool>

Allow the backend to send updates on its own initiative