Structs
- Console
Profile Finished - Console
Profile Finished Params - Console
Profile Started - Sent when new profile recording is started using console.profile() call. consoleProfileStarted
- Console
Profile Started Params - Sent when new profile recording is started using console.profile() call. consoleProfileStarted
- Precise
Coverage Delta Update - Reports coverage delta since the last poll (either from an event like this, or from
takePreciseCoveragefor the current isolate. May only be sent if precise code coverage has been started. This event can be trigged by the embedder to, for example, trigger collection of coverage data immediately at a certain point in time. preciseCoverageDeltaUpdate - Precise
Coverage Delta Update Params - Reports coverage delta since the last poll (either from an event like this, or from
takePreciseCoveragefor the current isolate. May only be sent if precise code coverage has been started. This event can be trigged by the embedder to, for example, trigger collection of coverage data immediately at a certain point in time. preciseCoverageDeltaUpdate