pub struct PreciseCoverageDeltaUpdate {
pub method: PreciseCoverageDeltaUpdateMethod,
pub params: PreciseCoverageDeltaUpdateParams,
}Expand description
Reports coverage delta since the last poll (either from an event like this, or from
takePreciseCoverage for the current isolate. May only be sent if precise code
coverage has been started. This event can be trigged by the embedder to, for example,
trigger collection of coverage data immediately at a certain point in time.
preciseCoverageDeltaUpdate
Fields
method: PreciseCoverageDeltaUpdateMethodparams: PreciseCoverageDeltaUpdateParamsImplementations
Sourceimpl PreciseCoverageDeltaUpdate
impl PreciseCoverageDeltaUpdate
pub const IDENTIFIER: &'static str = "Profiler.preciseCoverageDeltaUpdate"
pub fn identifier(&self) -> &'static str