pub struct AddBinding {
pub method: AddBindingMethod,
pub params: AddBindingParams,
}Expand description
If executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification. addBinding
Fields
method: AddBindingMethodparams: AddBindingParamsImplementations
Sourceimpl AddBinding
impl AddBinding
pub fn builder() -> AddBindingBuilder
Sourceimpl AddBinding
impl AddBinding
pub const IDENTIFIER: &'static str = "Runtime.addBinding"
pub fn identifier(&self) -> &'static str