pub struct CallFunctionOn {
pub method: CallFunctionOnMethod,
pub params: CallFunctionOnParams,
}Expand description
Calls function with given declaration on the given object. Object group of the result is inherited from the target object. callFunctionOn
Fields
method: CallFunctionOnMethodparams: CallFunctionOnParamsImplementations
Sourceimpl CallFunctionOn
impl CallFunctionOn
pub fn builder() -> CallFunctionOnBuilder
Sourceimpl CallFunctionOn
impl CallFunctionOn
pub const IDENTIFIER: &'static str = "Runtime.callFunctionOn"
pub fn identifier(&self) -> &'static str