pub struct Enable {
pub method: EnableMethod,
pub params: EnableParams,
}Expand description
Enables reporting of execution contexts creation by means of executionContextCreated event.
When the reporting gets enabled the event will be sent immediately for each existing execution
context.
enable
Fields
method: EnableMethodparams: EnableParamsImplementations
Sourceimpl Enable
impl Enable
pub const IDENTIFIER: &'static str = "Runtime.enable"
pub fn identifier(&self) -> &'static str