GetExceptionDetails

Struct GetExceptionDetails 

pub struct GetExceptionDetails {
    pub method: GetExceptionDetailsMethod,
    pub params: GetExceptionDetailsParams,
}
This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown. getExceptionDetails

Fields

method: GetExceptionDetailsMethodparams: GetExceptionDetailsParams

Implementations

Source

impl GetExceptionDetails

Source

impl GetExceptionDetails

pub const IDENTIFIER: &'static str = "Runtime.getExceptionDetails"

pub fn identifier(&self) -> &'static str