pub struct GetExceptionDetailsParams {
pub error_object_id: RemoteObjectId,
}Expand description
This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown. getExceptionDetails
Fields
error_object_id: RemoteObjectIdThe error object for which to resolve the exception details.
Implementations
Sourceimpl GetExceptionDetailsParams
impl GetExceptionDetailsParams
pub fn new(error_object_id: impl Into<RemoteObjectId>) -> Self