pub struct GlobalLexicalScopeNamesParams {
pub execution_context_id: Option<ExecutionContextId>,
}Expand description
Returns all let, const and class variables from global scope. globalLexicalScopeNames
Fields
execution_context_id: Option<ExecutionContextId>Specifies in which execution context to lookup global scope variables.