pub struct RemoveBinding {
pub method: RemoveBindingMethod,
pub params: RemoveBindingParams,
}Expand description
This method does not remove binding function from global object but unsubscribes current runtime agent from Runtime.bindingCalled notifications. removeBinding
Fields
method: RemoveBindingMethodparams: RemoveBindingParamsImplementations
Sourceimpl RemoveBinding
impl RemoveBinding
pub fn builder() -> RemoveBindingBuilder
Sourceimpl RemoveBinding
impl RemoveBinding
pub const IDENTIFIER: &'static str = "Runtime.removeBinding"
pub fn identifier(&self) -> &'static str