Module events

Module events 

Structs

BindingCalled
Notification is issued every time when binding is called. bindingCalled
BindingCalledParams
Notification is issued every time when binding is called. bindingCalled
ConsoleApiCalled
Issued when console API was called. consoleAPICalled
ConsoleApiCalledParams
Issued when console API was called. consoleAPICalled
ExceptionRevoked
Issued when unhandled exception was revoked. exceptionRevoked
ExceptionRevokedParams
Issued when unhandled exception was revoked. exceptionRevoked
ExceptionThrown
Issued when exception was thrown and unhandled. exceptionThrown
ExceptionThrownParams
Issued when exception was thrown and unhandled. exceptionThrown
ExecutionContextCreated
Issued when new execution context is created. executionContextCreated
ExecutionContextCreatedParams
Issued when new execution context is created. executionContextCreated
ExecutionContextDestroyed
Issued when execution context is destroyed. executionContextDestroyed
ExecutionContextDestroyedParams
Issued when execution context is destroyed. executionContextDestroyed
ExecutionContextsCleared
Issued when all executionContexts were cleared in browser executionContextsCleared
ExecutionContextsClearedParams
Issued when all executionContexts were cleared in browser executionContextsCleared
InspectRequested
Issued when object should be inspected (for example, as a result of inspect() command line API call). inspectRequested
InspectRequestedParams
Issued when object should be inspected (for example, as a result of inspect() command line API call). inspectRequested

Enums

BindingCalledMethod
ConsoleApiCalledMethod
ConsoleApiCalledType
Type of the call.
ExceptionRevokedMethod
ExceptionThrownMethod
ExecutionContextCreatedMethod
ExecutionContextDestroyedMethod
ExecutionContextsClearedMethod
InspectRequestedMethod
RuntimeEvents