ConsoleApiCalledParams

Struct ConsoleApiCalledParams 

pub struct ConsoleApiCalledParams {
    pub type: ConsoleApiCalledType,
    pub args: Vec<RemoteObject>,
    pub execution_context_id: ExecutionContextId,
    pub timestamp: Timestamp,
    pub stack_trace: Option<StackTrace>,
    pub context: Option<String>,
}
Issued when console API was called. consoleAPICalled

Fields

type: ConsoleApiCalledType

Type of the call.

args: Vec<RemoteObject>

Call arguments.

execution_context_id: ExecutionContextId

Identifier of the context where the call was made.

timestamp: Timestamp

Call timestamp.

stack_trace: Option<StackTrace>

Stack trace captured when the call was made. The async stack chain is automatically reported for the following call types: assert, error, trace, warning. For other types the async call chain can be retrieved using Debugger.getStackTrace and stackTrace.parentId field.

context: Option<String>

Console context descriptor for calls on non-default console context (not console.*): ‘anonymous#unique-logger-id’ for call on unnamed context, ‘name#unique-logger-id’ for call on named context.