Structs
- Check
Contrast - Runs the contrast check for the target page. Found issues are reported using Audits.issueAdded event. checkContrast
- Check
Contrast Params - Runs the contrast check for the target page. Found issues are reported using Audits.issueAdded event. checkContrast
- Check
Forms Issues - Runs the form issues check for the target page. Found issues are reported using Audits.issueAdded event. checkFormsIssues
- Check
Forms Issues Params - Runs the form issues check for the target page. Found issues are reported using Audits.issueAdded event. checkFormsIssues
- Disable
- Disables issues domain, prevents further issues from being reported to the client. disable
- Disable
Params - Disables issues domain, prevents further issues from being reported to the client. disable
- Enable
- Enables issues domain, sends the issues collected so far to the client by means of the
issueAddedevent. enable - Enable
Params - Enables issues domain, sends the issues collected so far to the client by means of the
issueAddedevent. enable - GetEncoded
Response - Returns the response body and size if it were re-encoded with the specified settings. Only applies to images. getEncodedResponse
- GetEncoded
Response Params - Returns the response body and size if it were re-encoded with the specified settings. Only applies to images. getEncodedResponse