pub struct RequestChildNodes {
pub method: RequestChildNodesMethod,
pub params: RequestChildNodesParams,
}Expand description
Requests that children of the node with given id are returned to the caller in form of
setChildNodes events where not only immediate children are retrieved, but all children down to
the specified depth.
requestChildNodes
Fields
method: RequestChildNodesMethodparams: RequestChildNodesParamsImplementations
Sourceimpl RequestChildNodes
impl RequestChildNodes
pub fn builder() -> RequestChildNodesBuilder
Sourceimpl RequestChildNodes
impl RequestChildNodes
pub const IDENTIFIER: &'static str = "DOM.requestChildNodes"
pub fn identifier(&self) -> &'static str