pub struct RequestNode {
pub method: RequestNodeMethod,
pub params: RequestNodeParams,
}Expand description
Requests that the node is sent to the caller given the JavaScript node object reference. All
nodes that form the path from the node to the root are also sent to the client as a series of
setChildNodes notifications.
requestNode
Fields
method: RequestNodeMethodparams: RequestNodeParamsImplementations
Sourceimpl RequestNode
impl RequestNode
pub fn builder() -> RequestNodeBuilder
Sourceimpl RequestNode
impl RequestNode
pub const IDENTIFIER: &'static str = "DOM.requestNode"
pub fn identifier(&self) -> &'static str