Clears a device posture override set with either setDeviceMetricsOverride()
or setDevicePostureOverride() and starts using posture information from the
platform again.
Does nothing if no override is set.
clearDevicePostureOverride
Clears a device posture override set with either setDeviceMetricsOverride()
or setDevicePostureOverride() and starts using posture information from the
platform again.
Does nothing if no override is set.
clearDevicePostureOverride
Clears the display features override set with either setDeviceMetricsOverride()
or setDisplayFeaturesOverride() and starts using display features from the
platform again.
Does nothing if no override is set.
clearDisplayFeaturesOverride
Clears the display features override set with either setDeviceMetricsOverride()
or setDisplayFeaturesOverride() and starts using display features from the
platform again.
Does nothing if no override is set.
clearDisplayFeaturesOverride
Returns device’s screen configuration. In headful mode, the physical screens configuration is returned,
whereas in headless mode, a virtual headless screen configuration is provided instead.
getScreenInfos
Returns device’s screen configuration. In headful mode, the physical screens configuration is returned,
whereas in headless mode, a virtual headless screen configuration is provided instead.
getScreenInfos
Sets or clears an override of the default background color of the frame. This override is used
if the content does not specify one.
setDefaultBackgroundColorOverride
Sets or clears an override of the default background color of the frame. This override is used
if the content does not specify one.
setDefaultBackgroundColorOverride
Overrides the values of device screen dimensions (window.screen.width, window.screen.height,
window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media
query results).
setDeviceMetricsOverride
Overrides the values of device screen dimensions (window.screen.width, window.screen.height,
window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media
query results).
setDeviceMetricsOverride
Start reporting the given posture value to the Device Posture API.
This override can also be set in setDeviceMetricsOverride().
setDevicePostureOverride
Start reporting the given posture value to the Device Posture API.
This override can also be set in setDeviceMetricsOverride().
setDevicePostureOverride
Start using the given display features to pupulate the Viewport Segments API.
This override can also be set in setDeviceMetricsOverride().
setDisplayFeaturesOverride
Start using the given display features to pupulate the Viewport Segments API.
This override can also be set in setDeviceMetricsOverride().
setDisplayFeaturesOverride
Provides a given pressure data set that will be processed and eventually be
delivered to PressureObserver users. |source| must have been previously
overridden by setPressureSourceOverrideEnabled.
setPressureDataOverride
Provides a given pressure data set that will be processed and eventually be
delivered to PressureObserver users. |source| must have been previously
overridden by setPressureSourceOverrideEnabled.
setPressureDataOverride
Overrides a pressure source of a given type, as used by the Compute
Pressure API, so that updates to PressureObserver.observe() are provided
via setPressureStateOverride instead of being retrieved from
platform-provided telemetry data.
setPressureSourceOverrideEnabled
Overrides a pressure source of a given type, as used by the Compute
Pressure API, so that updates to PressureObserver.observe() are provided
via setPressureStateOverride instead of being retrieved from
platform-provided telemetry data.
setPressureSourceOverrideEnabled
TODO: OBSOLETE: To remove when setPressureDataOverride is merged.
Provides a given pressure state that will be processed and eventually be
delivered to PressureObserver users. |source| must have been previously
overridden by setPressureSourceOverrideEnabled.
setPressureStateOverride
TODO: OBSOLETE: To remove when setPressureDataOverride is merged.
Provides a given pressure state that will be processed and eventually be
delivered to PressureObserver users. |source| must have been previously
overridden by setPressureSourceOverrideEnabled.
setPressureStateOverride
Overrides the values for env(safe-area-inset-) and env(safe-area-max-inset-). Unset values will cause the
respective variables to be undefined, even if previously overridden.
setSafeAreaInsetsOverride
Overrides the values for env(safe-area-inset-) and env(safe-area-max-inset-). Unset values will cause the
respective variables to be undefined, even if previously overridden.
setSafeAreaInsetsOverride
Overrides a platform sensor of a given type. If |enabled| is true, calls to
Sensor.start() will use a virtual sensor as backend rather than fetching
data from a real hardware sensor. Otherwise, existing virtual
sensor-backend Sensor objects will fire an error event and new calls to
Sensor.start() will attempt to use a real sensor instead.
setSensorOverrideEnabled
Overrides a platform sensor of a given type. If |enabled| is true, calls to
Sensor.start() will use a virtual sensor as backend rather than fetching
data from a real hardware sensor. Otherwise, existing virtual
sensor-backend Sensor objects will fire an error event and new calls to
Sensor.start() will attempt to use a real sensor instead.
setSensorOverrideEnabled
Allows overriding the difference between the small and large viewport sizes, which determine the
value of the svh and lvh unit, respectively. Only supported for top-level frames.
setSmallViewportHeightDifferenceOverride
Allows overriding the difference between the small and large viewport sizes, which determine the
value of the svh and lvh unit, respectively. Only supported for top-level frames.
setSmallViewportHeightDifferenceOverride
Turns on virtual time for all frames (replacing real-time with a synthetic time source) and sets
the current virtual time policy. Note this supersedes any previous time budget.
setVirtualTimePolicy
Turns on virtual time for all frames (replacing real-time with a synthetic time source) and sets
the current virtual time policy. Note this supersedes any previous time budget.
setVirtualTimePolicy
Vision deficiency to emulate. Order: best-effort emulations come first, followed by any
physiologically accurate emulations for medically recognized color vision deficiencies.