pub struct ClearDisplayFeaturesOverride {
pub method: ClearDisplayFeaturesOverrideMethod,
pub params: ClearDisplayFeaturesOverrideParams,
}Expand description
Clears the display features override set with either setDeviceMetricsOverride() or setDisplayFeaturesOverride() and starts using display features from the platform again. Does nothing if no override is set. clearDisplayFeaturesOverride
Fields
method: ClearDisplayFeaturesOverrideMethodparams: ClearDisplayFeaturesOverrideParamsImplementations
Sourceimpl ClearDisplayFeaturesOverride
impl ClearDisplayFeaturesOverride
pub fn builder() -> ClearDisplayFeaturesOverrideBuilder
Sourceimpl ClearDisplayFeaturesOverride
impl ClearDisplayFeaturesOverride
pub const IDENTIFIER: &'static str = "Emulation.clearDisplayFeaturesOverride"
pub fn identifier(&self) -> &'static str