Structs
- Clear
Storage Items - Clears extension storage in the given
storageArea. clearStorageItems - Clear
Storage Items Params - Clears extension storage in the given
storageArea. clearStorageItems - GetExtensions
- Gets a list of all unpacked extensions. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. getExtensions
- GetExtensions
Params - Gets a list of all unpacked extensions. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. getExtensions
- GetStorage
Items - Gets data from extension storage in the given
storageArea. Ifkeysis specified, these are used to filter the result. getStorageItems - GetStorage
Items Params - Gets data from extension storage in the given
storageArea. Ifkeysis specified, these are used to filter the result. getStorageItems - Load
Unpacked - Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. loadUnpacked
- Load
Unpacked Params - Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. loadUnpacked
- Remove
Storage Items - Removes
keysfrom extension storage in the givenstorageArea. removeStorageItems - Remove
Storage Items Params - Removes
keysfrom extension storage in the givenstorageArea. removeStorageItems - SetStorage
Items - Sets
valuesin extension storage in the givenstorageArea. The providedvalueswill be merged with existing values in the storage area. setStorageItems - SetStorage
Items Params - Sets
valuesin extension storage in the givenstorageArea. The providedvalueswill be merged with existing values in the storage area. setStorageItems - Trigger
Action - Runs an extension default action. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. triggerAction
- Trigger
Action Params - Runs an extension default action. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set. triggerAction
- Uninstall
- Uninstalls an unpacked extension (others not supported) from the profile. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging. uninstall
- Uninstall
Params - Uninstalls an unpacked extension (others not supported) from the profile. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging. uninstall