pub struct RequestPausedParams {
pub request_id: RequestId,
pub request: Request,
pub frame_id: FrameId,
pub resource_type: ResourceType,
pub response_error_reason: Option<ErrorReason>,
pub response_status_code: Option<i64>,
pub response_status_text: Option<String>,
pub response_headers: Option<Vec<HeaderEntry>>,
pub network_id: Option<RequestId>,
pub redirected_request_id: Option<RequestId>,
}Expand description
Issued when the domain is enabled and the request URL matches the
specified filter. The request is paused until the client responds
with one of continueRequest, failRequest or fulfillRequest.
The stage of the request can be determined by presence of responseErrorReason
and responseStatusCode – the request is at the response stage if either
of these fields is present and in the request stage otherwise.
Redirect responses and subsequent requests are reported similarly to regular
responses and requests. Redirect responses may be distinguished by the value
of responseStatusCode (which is one of 301, 302, 303, 307, 308) along with
presence of the location header. Requests resulting from a redirect will
have redirectedRequestId field set.
requestPaused
Fields
request_id: RequestIdEach request the page makes will have a unique id.
request: RequestThe details of the request.
frame_id: FrameIdThe id of the frame that initiated the request.
resource_type: ResourceTypeHow the requested resource will be used.
response_error_reason: Option<ErrorReason>Response error if intercepted at response stage.
response_status_code: Option<i64>Response code if intercepted at response stage.
response_status_text: Option<String>Response status text if intercepted at response stage.
response_headers: Option<Vec<HeaderEntry>>Response headers if intercepted at the response stage.
network_id: Option<RequestId>If the intercepted request had a corresponding Network.requestWillBeSent event fired for it, then this networkId will be the same as the requestId present in the requestWillBeSent event.
redirected_request_id: Option<RequestId>If the request is due to a redirect response from the server, the id of the request that has caused the redirect.