pub struct ImeSetComposition {
pub method: ImeSetCompositionMethod,
pub params: ImeSetCompositionParams,
}Expand description
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition. imeSetComposition
Fields
method: ImeSetCompositionMethodparams: ImeSetCompositionParamsImplementations
Sourceimpl ImeSetComposition
impl ImeSetComposition
pub fn builder() -> ImeSetCompositionBuilder
Sourceimpl ImeSetComposition
impl ImeSetComposition
pub const IDENTIFIER: &'static str = "Input.imeSetComposition"
pub fn identifier(&self) -> &'static str