pub struct RequestWillBeSentExtraInfoParams {
pub request_id: RequestId,
pub associated_cookies: Vec<AssociatedCookie>,
pub headers: Headers,
pub connect_timing: ConnectTiming,
pub device_bound_session_usages: Option<Vec<DeviceBoundSessionWithUsage>>,
pub client_security_state: Option<ClientSecurityState>,
pub site_has_cookie_in_other_partition: Option<bool>,
pub applied_network_conditions_id: Option<String>,
}Expand description
Fired when additional information about a requestWillBeSent event is available from the network stack. Not every requestWillBeSent event will have an additional requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent or requestWillBeSentExtraInfo will be fired first for the same request. requestWillBeSentExtraInfo
Fields
request_id: RequestIdRequest identifier. Used to match this information to an existing requestWillBeSent event.
A list of cookies potentially associated to the requested URL. This includes both cookies sent with the request and the ones not sent; the latter are distinguished by having blockedReasons field set.
headers: HeadersRaw request headers as they will be sent over the wire.
connect_timing: ConnectTimingConnection timing information for the request.
device_bound_session_usages: Option<Vec<DeviceBoundSessionWithUsage>>How the request site’s device bound sessions were used during this request.
client_security_state: Option<ClientSecurityState>The client security state set for the request.
Whether the site has partitioned cookies stored in a partition different than the current one.
applied_network_conditions_id: Option<String>The network conditions id if this request was affected by network conditions configured via emulateNetworkConditionsByRule.