pub struct TrustTokenOperationDone {
pub method: TrustTokenOperationDoneMethod,
pub params: TrustTokenOperationDoneParams,
}Expand description
Fired exactly once for each Trust Token operation. Depending on the type of the operation and whether the operation succeeded or failed, the event is fired before the corresponding request was sent or after the response was received. trustTokenOperationDone
Fields
method: TrustTokenOperationDoneMethodparams: TrustTokenOperationDoneParamsImplementations
Sourceimpl TrustTokenOperationDone
impl TrustTokenOperationDone
pub const IDENTIFIER: &'static str = "Network.trustTokenOperationDone"
pub fn identifier(&self) -> &'static str