pub struct JavascriptDialogOpeningParams {
pub url: String,
pub frame_id: Box<FrameId>,
pub message: String,
pub type: DialogType,
pub has_browser_handler: bool,
pub default_prompt: Option<String>,
}Expand description
Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) is about to open. javascriptDialogOpening
Fields
url: StringFrame url.
frame_id: Box<FrameId>Frame id.
message: StringMessage that will be displayed by the dialog.
type: DialogTypeDialog type.
has_browser_handler: boolTrue iff browser is capable showing or acting on the given dialog. When browser has no dialog handler for given target, calling alert while Page domain is engaged will stall the page execution. Execution can be resumed via calling Page.handleJavaScriptDialog.
default_prompt: Option<String>Default dialog prompt.