pub struct ChangeAppUserSettings {
pub method: ChangeAppUserSettingsMethod,
pub params: ChangeAppUserSettingsParams,
}Expand description
Changes user settings of the web app identified by its manifestId. If the app was not installed, this command returns an error. Unset parameters will be ignored; unrecognized values will cause an error.
Unlike the ones defined in the manifest files of the web apps, these settings are provided by the browser and controlled by the users, they impact the way the browser handling the web apps.
See the comment of each parameter. changeAppUserSettings
Fields
method: ChangeAppUserSettingsMethodparams: ChangeAppUserSettingsParamsImplementations
Sourceimpl ChangeAppUserSettings
impl ChangeAppUserSettings
pub fn builder() -> ChangeAppUserSettingsBuilder
Sourceimpl ChangeAppUserSettings
impl ChangeAppUserSettings
pub const IDENTIFIER: &'static str = "PWA.changeAppUserSettings"
pub fn identifier(&self) -> &'static str