Skip to main content Module commands Copy item path Source ClearCookies Clears cookies.
clearCookies ClearCookiesParams Clears cookies.
clearCookies ClearDataForOrigin Clears storage for origin.
clearDataForOrigin ClearDataForOriginParams Clears storage for origin.
clearDataForOrigin ClearDataForStorageKey Clears storage for storage key.
clearDataForStorageKey ClearDataForStorageKeyParams Clears storage for storage key.
clearDataForStorageKey ClearSharedStorageEntries Clears all entries for a given origin’s shared storage.
clearSharedStorageEntries ClearSharedStorageEntriesParams Clears all entries for a given origin’s shared storage.
clearSharedStorageEntries ClearTrustTokens Removes all Trust Tokens issued by the provided issuerOrigin.
Leaves other stored data, including the issuer’s Redemption Records, intact.
clearTrustTokens ClearTrustTokensParams Removes all Trust Tokens issued by the provided issuerOrigin.
Leaves other stored data, including the issuer’s Redemption Records, intact.
clearTrustTokens DeleteSharedStorageEntry Deletes entry for key (if it exists) for a given origin’s shared storage.
deleteSharedStorageEntry DeleteSharedStorageEntryParams Deletes entry for key (if it exists) for a given origin’s shared storage.
deleteSharedStorageEntry DeleteStorageBucket Deletes the Storage Bucket with the given storage key and bucket name.
deleteStorageBucket DeleteStorageBucketParams Deletes the Storage Bucket with the given storage key and bucket name.
deleteStorageBucket GetAffectedUrlsForThirdPartyCookieMetadata Returns the list of URLs from a page and its embedded resources that match
existing grace period URL pattern rules.
https://developers.google.com/privacy-sandbox/cookies/temporary-exceptions/grace-period
getAffectedUrlsForThirdPartyCookieMetadata GetAffectedUrlsForThirdPartyCookieMetadataParams Returns the list of URLs from a page and its embedded resources that match
existing grace period URL pattern rules.
https://developers.google.com/privacy-sandbox/cookies/temporary-exceptions/grace-period
getAffectedUrlsForThirdPartyCookieMetadata GetCookies Returns all browser cookies.
getCookies GetCookiesParams Returns all browser cookies.
getCookies GetInterestGroupDetails Gets details for a named interest group.
getInterestGroupDetails GetInterestGroupDetailsParams Gets details for a named interest group.
getInterestGroupDetails GetRelatedWebsiteSets Returns the effective Related Website Sets in use by this profile for the browser
session. The effective Related Website Sets will not change during a browser session.
getRelatedWebsiteSets GetRelatedWebsiteSetsParams Returns the effective Related Website Sets in use by this profile for the browser
session. The effective Related Website Sets will not change during a browser session.
getRelatedWebsiteSets GetSharedStorageEntries Gets the entries in an given origin’s shared storage.
getSharedStorageEntries GetSharedStorageEntriesParams Gets the entries in an given origin’s shared storage.
getSharedStorageEntries GetSharedStorageMetadata Gets metadata for an origin’s shared storage.
getSharedStorageMetadata GetSharedStorageMetadataParams Gets metadata for an origin’s shared storage.
getSharedStorageMetadata GetStorageKey Returns storage key for the given frame. If no frame ID is provided,
the storage key of the target executing this command is returned.
getStorageKey GetStorageKeyParams Returns storage key for the given frame. If no frame ID is provided,
the storage key of the target executing this command is returned.
getStorageKey GetTrustTokens Returns the number of stored Trust Tokens per issuer for the
current browsing context.
getTrustTokens GetTrustTokensParams Returns the number of stored Trust Tokens per issuer for the
current browsing context.
getTrustTokens GetUsageAndQuota Returns usage and quota in bytes.
getUsageAndQuota GetUsageAndQuotaParams Returns usage and quota in bytes.
getUsageAndQuota OverrideQuotaForOrigin Override quota for the specified origin
overrideQuotaForOrigin OverrideQuotaForOriginParams Override quota for the specified origin
overrideQuotaForOrigin ResetSharedStorageBudget Resets the budget for ownerOrigin by clearing all budget withdrawals.
resetSharedStorageBudget ResetSharedStorageBudgetParams Resets the budget for ownerOrigin by clearing all budget withdrawals.
resetSharedStorageBudget RunBounceTrackingMitigations Deletes state for sites identified as potential bounce trackers, immediately.
runBounceTrackingMitigations RunBounceTrackingMitigationsParams Deletes state for sites identified as potential bounce trackers, immediately.
runBounceTrackingMitigations SendPendingAttributionReports Sends all pending Attribution Reports immediately, regardless of their
scheduled report time.
sendPendingAttributionReports SendPendingAttributionReportsParams Sends all pending Attribution Reports immediately, regardless of their
scheduled report time.
sendPendingAttributionReports SetAttributionReportingLocalTestingMode https://wicg.github.io/attribution-reporting-api/
setAttributionReportingLocalTestingMode SetAttributionReportingLocalTestingModeParams https://wicg.github.io/attribution-reporting-api/
setAttributionReportingLocalTestingMode SetAttributionReportingTracking Enables/disables issuing of Attribution Reporting events.
setAttributionReportingTracking SetAttributionReportingTrackingParams Enables/disables issuing of Attribution Reporting events.
setAttributionReportingTracking SetCookies Sets given cookies.
setCookies SetCookiesParams Sets given cookies.
setCookies SetInterestGroupAuctionTracking Enables/Disables issuing of interestGroupAuctionEventOccurred and
interestGroupAuctionNetworkRequestCreated.
setInterestGroupAuctionTracking SetInterestGroupAuctionTrackingParams Enables/Disables issuing of interestGroupAuctionEventOccurred and
interestGroupAuctionNetworkRequestCreated.
setInterestGroupAuctionTracking SetInterestGroupTracking Enables/Disables issuing of interestGroupAccessed events.
setInterestGroupTracking SetInterestGroupTrackingParams Enables/Disables issuing of interestGroupAccessed events.
setInterestGroupTracking SetProtectedAudienceKAnonymity SetProtectedAudienceKAnonymityParams SetSharedStorageEntry Sets entry with key and value for a given origin’s shared storage.
setSharedStorageEntry SetSharedStorageEntryParams Sets entry with key and value for a given origin’s shared storage.
setSharedStorageEntry SetSharedStorageTracking Enables/disables issuing of sharedStorageAccessed events.
setSharedStorageTracking SetSharedStorageTrackingParams Enables/disables issuing of sharedStorageAccessed events.
setSharedStorageTracking SetStorageBucketTracking Set tracking for a storage key’s buckets.
setStorageBucketTracking SetStorageBucketTrackingParams Set tracking for a storage key’s buckets.
setStorageBucketTracking TrackCacheStorageForOrigin Registers origin to be notified when an update occurs to its cache storage list.
trackCacheStorageForOrigin TrackCacheStorageForOriginParams Registers origin to be notified when an update occurs to its cache storage list.
trackCacheStorageForOrigin TrackCacheStorageForStorageKey Registers storage key to be notified when an update occurs to its cache storage list.
trackCacheStorageForStorageKey TrackCacheStorageForStorageKeyParams Registers storage key to be notified when an update occurs to its cache storage list.
trackCacheStorageForStorageKey TrackIndexedDbForOrigin Registers origin to be notified when an update occurs to its IndexedDB.
trackIndexedDBForOrigin TrackIndexedDbForOriginParams Registers origin to be notified when an update occurs to its IndexedDB.
trackIndexedDBForOrigin TrackIndexedDbForStorageKey Registers storage key to be notified when an update occurs to its IndexedDB.
trackIndexedDBForStorageKey TrackIndexedDbForStorageKeyParams Registers storage key to be notified when an update occurs to its IndexedDB.
trackIndexedDBForStorageKey UntrackCacheStorageForOrigin Unregisters origin from receiving notifications for cache storage.
untrackCacheStorageForOrigin UntrackCacheStorageForOriginParams Unregisters origin from receiving notifications for cache storage.
untrackCacheStorageForOrigin UntrackCacheStorageForStorageKey Unregisters storage key from receiving notifications for cache storage.
untrackCacheStorageForStorageKey UntrackCacheStorageForStorageKeyParams Unregisters storage key from receiving notifications for cache storage.
untrackCacheStorageForStorageKey UntrackIndexedDbForOrigin Unregisters origin from receiving notifications for IndexedDB.
untrackIndexedDBForOrigin UntrackIndexedDbForOriginParams Unregisters origin from receiving notifications for IndexedDB.
untrackIndexedDBForOrigin UntrackIndexedDbForStorageKey Unregisters storage key from receiving notifications for IndexedDB.
untrackIndexedDBForStorageKey UntrackIndexedDbForStorageKeyParams Unregisters storage key from receiving notifications for IndexedDB.
untrackIndexedDBForStorageKey ClearCookiesMethod ClearDataForOriginMethod ClearDataForStorageKeyMethod ClearSharedStorageEntriesMethod ClearTrustTokensMethod DeleteSharedStorageEntryMethod DeleteStorageBucketMethod GetAffectedUrlsForThirdPartyCookieMetadataMethod GetCookiesMethod GetInterestGroupDetailsMethod GetRelatedWebsiteSetsMethod GetSharedStorageEntriesMethod GetSharedStorageMetadataMethod GetStorageKeyMethod GetTrustTokensMethod GetUsageAndQuotaMethod OverrideQuotaForOriginMethod ResetSharedStorageBudgetMethod RunBounceTrackingMitigationsMethod SendPendingAttributionReportsMethod SetAttributionReportingLocalTestingModeMethod SetAttributionReportingTrackingMethod SetCookiesMethod SetInterestGroupAuctionTrackingMethod SetInterestGroupTrackingMethod SetProtectedAudienceKAnonymityMethod SetSharedStorageEntryMethod SetSharedStorageTrackingMethod SetStorageBucketTrackingMethod StorageCommands TrackCacheStorageForOriginMethod TrackCacheStorageForStorageKeyMethod TrackIndexedDbForOriginMethod TrackIndexedDbForStorageKeyMethod UntrackCacheStorageForOriginMethod UntrackCacheStorageForStorageKeyMethod UntrackIndexedDbForOriginMethod UntrackIndexedDbForStorageKeyMethod