pub struct SetAutoAttachParams {
pub auto_attach: bool,
pub wait_for_debugger_on_start: bool,
pub flatten: Option<bool>,
pub filter: Option<TargetFilter>,
}Expand description
Controls whether to automatically attach to new targets which are considered
to be directly related to this one (for example, iframes or workers).
When turned on, attaches to all existing related targets as well. When turned off,
automatically detaches from all currently attached targets.
This also clears all targets added by autoAttachRelated from the list of targets to watch
for creation of related targets.
You might want to call this recursively for auto-attached targets to attach
to all available targets.
setAutoAttach
Fields
auto_attach: boolWhether to auto-attach to related targets.
wait_for_debugger_on_start: boolWhether to pause new targets when attaching to them. Use Runtime.runIfWaitingForDebugger
to run paused targets.
flatten: Option<bool>Enables “flat” access to the session via specifying sessionId attribute in the commands. We plan to make this the default, deprecate non-flattened mode, and eventually retire it. See crbug.com/991325.
filter: Option<TargetFilter>Only targets matching filter will be attached.
Implementations