Structs
- AddCredential
- Adds the credential to the specified authenticator. addCredential
- AddCredential
Params - Adds the credential to the specified authenticator. addCredential
- AddVirtual
Authenticator - Creates and adds a virtual authenticator. addVirtualAuthenticator
- AddVirtual
Authenticator Params - Creates and adds a virtual authenticator. addVirtualAuthenticator
- Clear
Credentials - Clears all the credentials from the specified device. clearCredentials
- Clear
Credentials Params - Clears all the credentials from the specified device. clearCredentials
- Disable
- Disable the WebAuthn domain. disable
- Disable
Params - Disable the WebAuthn domain. disable
- Enable
- Enable the WebAuthn domain and start intercepting credential storage and retrieval with a virtual authenticator. enable
- Enable
Params - Enable the WebAuthn domain and start intercepting credential storage and retrieval with a virtual authenticator. enable
- GetCredential
- Returns a single credential stored in the given virtual authenticator that matches the credential ID. getCredential
- GetCredential
Params - Returns a single credential stored in the given virtual authenticator that matches the credential ID. getCredential
- GetCredentials
- Returns all the credentials stored in the given virtual authenticator. getCredentials
- GetCredentials
Params - Returns all the credentials stored in the given virtual authenticator. getCredentials
- Remove
Credential - Removes a credential from the authenticator. removeCredential
- Remove
Credential Params - Removes a credential from the authenticator. removeCredential
- Remove
Virtual Authenticator - Removes the given authenticator. removeVirtualAuthenticator
- Remove
Virtual Authenticator Params - Removes the given authenticator. removeVirtualAuthenticator
- SetAutomatic
Presence Simulation - Sets whether tests of user presence will succeed immediately (if true) or fail to resolve (if false) for an authenticator. The default is true. setAutomaticPresenceSimulation
- SetAutomatic
Presence Simulation Params - Sets whether tests of user presence will succeed immediately (if true) or fail to resolve (if false) for an authenticator. The default is true. setAutomaticPresenceSimulation
- SetCredential
Properties - Allows setting credential properties. https://w3c.github.io/webauthn/#sctn-automation-set-credential-properties setCredentialProperties
- SetCredential
Properties Params - Allows setting credential properties. https://w3c.github.io/webauthn/#sctn-automation-set-credential-properties setCredentialProperties
- SetResponse
Override Bits - Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present. setResponseOverrideBits
- SetResponse
Override Bits Params - Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present. setResponseOverrideBits
- SetUser
Verified - Sets whether User Verification succeeds or fails for an authenticator. The default is true. setUserVerified
- SetUser
Verified Params - Sets whether User Verification succeeds or fails for an authenticator. The default is true. setUserVerified
Enums
- AddCredential
Method - AddVirtual
Authenticator Method - Clear
Credentials Method - Disable
Method - Enable
Method - GetCredential
Method - GetCredentials
Method - Remove
Credential Method - Remove
Virtual Authenticator Method - SetAutomatic
Presence Simulation Method - SetCredential
Properties Method - SetResponse
Override Bits Method - SetUser
Verified Method - WebAuthn
Commands