pub struct NextWasmDisassemblyChunk {
pub method: NextWasmDisassemblyChunkMethod,
pub params: NextWasmDisassemblyChunkParams,
}Expand description
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors. nextWasmDisassemblyChunk
Fields
method: NextWasmDisassemblyChunkMethodparams: NextWasmDisassemblyChunkParamsImplementations
Sourceimpl NextWasmDisassemblyChunk
impl NextWasmDisassemblyChunk
pub const IDENTIFIER: &'static str = "Debugger.nextWasmDisassemblyChunk"
pub fn identifier(&self) -> &'static str