pub struct SetBlackboxedRanges {
pub method: SetBlackboxedRangesMethod,
pub params: SetBlackboxedRangesParams,
}Expand description
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted. setBlackboxedRanges
Fields
method: SetBlackboxedRangesMethodparams: SetBlackboxedRangesParamsImplementations
Sourceimpl SetBlackboxedRanges
impl SetBlackboxedRanges
pub fn builder() -> SetBlackboxedRangesBuilder
Sourceimpl SetBlackboxedRanges
impl SetBlackboxedRanges
pub const IDENTIFIER: &'static str = "Debugger.setBlackboxedRanges"
pub fn identifier(&self) -> &'static str