pub struct ScriptParsedParams {Show 21 fields
pub script_id: ScriptId,
pub url: String,
pub start_line: i64,
pub start_column: i64,
pub end_line: i64,
pub end_column: i64,
pub execution_context_id: ExecutionContextId,
pub hash: String,
pub build_id: String,
pub execution_context_aux_data: Option<Value>,
pub is_live_edit: Option<bool>,
pub source_map_url: Option<String>,
pub has_source_url: Option<bool>,
pub is_module: Option<bool>,
pub length: Option<i64>,
pub stack_trace: Option<StackTrace>,
pub code_offset: Option<i64>,
pub script_language: Option<ScriptLanguage>,
pub debug_symbols: Option<Vec<DebugSymbols>>,
pub embedder_name: Option<String>,
pub resolved_breakpoints: Option<Vec<ResolvedBreakpoint>>,
}Expand description
Fired when virtual machine parses script. This event is also fired for all known and uncollected scripts upon enabling debugger. scriptParsed
Fields
script_id: ScriptIdIdentifier of the script parsed.
url: StringURL or name of the script parsed (if any).
start_line: i64Line offset of the script within the resource with given URL (for script tags).
start_column: i64Column offset of the script within the resource with given URL.
end_line: i64Last line of the script.
end_column: i64Length of the last line of the script.
execution_context_id: ExecutionContextIdSpecifies script creation context.
hash: StringContent hash of the script, SHA-256.
build_id: StringFor Wasm modules, the content of the build_id custom section. For JavaScript the debugId magic comment.
execution_context_aux_data: Option<Value>Embedder-specific auxiliary data likely matching {isDefault: boolean, type: ‘default’|‘isolated’|‘worker’, frameId: string}
is_live_edit: Option<bool>True, if this script is generated as a result of the live edit operation.
source_map_url: Option<String>URL of source map associated with script (if any).
has_source_url: Option<bool>True, if this script has sourceURL.
is_module: Option<bool>True, if this script is ES6 module.
length: Option<i64>This script length.
stack_trace: Option<StackTrace>JavaScript top stack frame of where the script parsed event was triggered if available.
code_offset: Option<i64>If the scriptLanguage is WebAssembly, the code section offset in the module.
script_language: Option<ScriptLanguage>The language of the script.
debug_symbols: Option<Vec<DebugSymbols>>If the scriptLanguage is WebAssembly, the source of debug symbols for the module.
embedder_name: Option<String>The name the embedder supplied for this script.
resolved_breakpoints: Option<Vec<ResolvedBreakpoint>>The list of set breakpoints in this script if calls to setBreakpointByUrl
matches this script’s URL or hash. Clients that use this list can ignore the
breakpointResolved event. They are equivalent.