pub struct StartSamplingParams {
pub sampling_interval: Option<f64>,
pub stack_depth: Option<f64>,
pub include_objects_collected_by_major_gc: Option<bool>,
pub include_objects_collected_by_minor_gc: Option<bool>,
}Fields
sampling_interval: Option<f64>Average sample interval in bytes. Poisson distribution is used for the intervals. The default value is 32768 bytes.
stack_depth: Option<f64>Maximum stack depth. The default value is 128.
include_objects_collected_by_major_gc: Option<bool>By default, the sampling heap profiler reports only objects which are still alive when the profile is returned via getSamplingProfile or stopSampling, which is useful for determining what functions contribute the most to steady-state memory usage. This flag instructs the sampling heap profiler to also include information about objects discarded by major GC, which will show which functions cause large temporary memory usage or long GC pauses.
include_objects_collected_by_minor_gc: Option<bool>By default, the sampling heap profiler reports only objects which are still alive when the profile is returned via getSamplingProfile or stopSampling, which is useful for determining what functions contribute the most to steady-state memory usage. This flag instructs the sampling heap profiler to also include information about objects discarded by minor GC, which is useful when tuning a latency-sensitive application for minimal GC activity.