pub struct StartPreciseCoverage {
pub method: StartPreciseCoverageMethod,
pub params: StartPreciseCoverageParams,
}Expand description
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters. startPreciseCoverage
Fields
method: StartPreciseCoverageMethodparams: StartPreciseCoverageParamsImplementations
Sourceimpl StartPreciseCoverage
impl StartPreciseCoverage
pub fn builder() -> StartPreciseCoverageBuilder
Sourceimpl StartPreciseCoverage
impl StartPreciseCoverage
pub const IDENTIFIER: &'static str = "Profiler.startPreciseCoverage"
pub fn identifier(&self) -> &'static str